open Reason_parser

module Default = struct


  open Reason_omp.OCaml_411.Ast
  open Parsetree
  open Ast_helper

  let default_loc = ref Location.none

  let default_expr () =
    let id = Location.mkloc "merlin.hole" !default_loc in
    Exp.mk ~loc:!default_loc (Pexp_extension (id, PStr []))

  let default_pattern () = Pat.any ~loc:!default_loc ()

  let default_module_expr () = Mod.structure ~loc:!default_loc[]
  let default_module_type () = Mty.signature ~loc:!default_loc[]


  let value (type a) : a MenhirInterpreter.symbol -> a = function
    | MenhirInterpreter.T MenhirInterpreter.T_error -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_WITH -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_WHILE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_WHEN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_VIRTUAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_VAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_UNDERSCORE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_UIDENT -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_TYPE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_TRY -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_TRUE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_TO -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_TILDE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_THEN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SWITCH -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_STRUCT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_STRING -> ("", None, None)
    | MenhirInterpreter.T MenhirInterpreter.T_STAR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SLASHGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SIG -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SHARPOP -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_SHARPEQUAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SHARP -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SEMISEMI -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_SEMI -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_RPAREN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_REC -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_RBRACKET -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_RBRACE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_QUOTE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_QUESTION -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PUB -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PRI -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PREFIXOP -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_POSTFIXOP -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_PLUSEQ -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PLUSDOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PLUS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_PERCENT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_OR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_OPEN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_OF -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_OBJECT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_NONREC -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_NEW -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_NATIVEINT -> 0n
    | MenhirInterpreter.T MenhirInterpreter.T_MUTABLE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_MODULE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_MINUSGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_MINUSDOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_MINUS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LPAREN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LIDENT -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_LETOP -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_LET -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LESSUIDENT -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_LESSSLASHIDENTGREATER -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_LESSSLASHGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LESSIDENT -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_LESSGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LESSDOTDOTGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LESS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETPERCENTPERCENT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETPERCENT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETLESS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETBAR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKETAT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACKET -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACELESS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LBRACE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_LAZY -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_INT -> ("0", None)
    | MenhirInterpreter.T MenhirInterpreter.T_INITIALIZER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_INHERIT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_INFIXOP4 -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_INFIXOP3 -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_INFIXOP2 -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_INFIXOP1 -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_INFIXOP0 -> ""
    | MenhirInterpreter.T MenhirInterpreter.T_INCLUDE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_IN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_IF -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_GREATERRBRACE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_GREATERDOTDOTDOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_GREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_FUNCTOR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_FUNCTION -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_FUN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_FOR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_FLOAT -> ("0.0", None)
    | MenhirInterpreter.T MenhirInterpreter.T_FALSE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EXTERNAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EXCEPTION -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_ES6_FUN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EQUALGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EQUAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EOL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_EOF -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_END -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_ELSE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DOWNTO -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DOTDOTDOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DOTDOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DOT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DONE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_DOCSTRING -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_DO -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_CONSTRAINT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_COMMENT -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_COMMA -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_COLONGREATER -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_COLONEQUAL -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_COLONCOLON -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_COLON -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_CLASS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_CHAR -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_BEGIN -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_BARRBRACKET -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_BARBAR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_BAR -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_BANG -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_BACKQUOTE -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_ASSERT -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_AS -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_ANDOP -> raise Not_found
    | MenhirInterpreter.T MenhirInterpreter.T_AND -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_AMPERSAND -> ()
    | MenhirInterpreter.T MenhirInterpreter.T_AMPERAMPER -> ()
    | MenhirInterpreter.N MenhirInterpreter.N_with_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_virtual_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_value_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_value -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_val_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_val_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_use_file_no_mapper -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_use_file -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_unattributed_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_unattributed_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_variance -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_variables_with_variance_comma_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_variables_with_variance -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_variable_with_variance -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_variable -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_subst_other_kind -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_subst_kind -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_subst_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_subst_constructor_declarations_aux -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_subst_constructor_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_parameters -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_parameter -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_other_kind -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_declaration_kind -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_declaration_details -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_type_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_toplevel_phrase -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_toplevel_directive -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_tag_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_structure_item -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_structure -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_string_literal_labels -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_string_literal_label -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_string_literal_exprs_maybe_punned -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_string_literal_expr_maybe_punned_with_comma -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_string_literal_expr_maybe_punned -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_str_type_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_str_exception_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_single_attr_id -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_pattern_not_ident_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_pattern_not_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_pattern_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_pattern_direct_argument -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_pattern -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_module_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_expr_template_constructor -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_expr_no_constructor -> default_expr ()
    | MenhirInterpreter.N MenhirInterpreter.N_simple_expr_no_call -> default_expr ()
    | MenhirInterpreter.N MenhirInterpreter.N_simple_expr_direct_argument -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_simple_expr_call -> (default_expr (), [])
    | MenhirInterpreter.N MenhirInterpreter.N_signed_constant -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_signature_items -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_signature_item -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_signature -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_sig_type_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_sig_exception_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_seq_expr_no_seq -> default_expr ()
    | MenhirInterpreter.N MenhirInterpreter.N_seq_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_separated_nonempty_list_AMPERSAND_non_arrowed_simple_core_types_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_row_field_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_row_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_record_label_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_record_expr_with_string_keys -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_record_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_record_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_rec_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_protected_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_primitive_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_poly_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_payload -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_pattern_without_or -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_pattern_optional_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_pattern_constructor_argument -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_pattern_comma_list_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_pattern -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_parse_pattern -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_parse_expression -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_parse_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_parenthesized_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_package_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_override_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_optional_expr_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_optional -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_type_constraint_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_WHEN_expr__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLONGREATER_core_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_simple_module_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_poly_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_non_arrowed_core_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_expr__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_core_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_preceded_COLON_class_constructor_type__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_item_extension_sugar_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_constructor_arguments_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_as_loc_preceded_AS_LIDENT___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_SEMI_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_OF_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_MODULE_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_LET_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_DOTDOTDOT_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_DOT_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_option_COMMA_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_opt_LET_MODULE_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_opt_LET_MODULE_REC_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_opt_LET_MODULE -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_operator -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_open_description -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_open_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_object_record_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_object_label_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_object_label_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_object_body_class_fields -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_object_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonrec_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_preceded_CONSTRAINT_constrain__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_name_tag_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_attributed_ext_constructor_extension_constructor_declaration__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_attributed_ext_constructor_either_extension_constructor_declaration_extension_constructor_rebind___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_as_loc_preceded_QUOTE_ident___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_as_loc_attribute__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list_as_loc_LIDENT__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_nonempty_list___anonymous_31_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_non_labeled_argument_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_non_arrowed_simple_core_types -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_non_arrowed_simple_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_non_arrowed_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mutable_or_virtual_flags -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mutable_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mty_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_type_signature -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_type_body_EQUAL_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_type_body_COLON_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_parameter -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_expr_structure -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_expr_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_complex_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_binding_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_arguments_comma_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_module_arguments -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_ext_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_ext_lesslongident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_ext_less_apply -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_mod_ext_apply -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_method_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_match_case_seq_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_match_case_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_SEMI_class_sig_field_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_SEMI_class_field_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_uncurried_labeled_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_uncurried_arrow_type_parameter_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_type_variable_with_variance_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_type_parameter_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_string_literal_label_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_string_literal_expr_maybe_punned_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_record_label_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_protected_type_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_pattern_optional_constraint_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_opt_spread_pattern__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_opt_spread_lbl_expr__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_opt_spread_expr_optional_constraint__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_object_label_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_module_parameter_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_module_complex_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_mod_ext_longident_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_labeled_pattern_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_field_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_expr_optional_constraint_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_COMMA_core_type_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lseparated_nonempty_list_aux_AND_with_constraint_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_type_parameters_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_terminated_pattern_comma_list_option_COMMA___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_row_field_list_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_preceded_GREATER_nonempty_list_name_tag___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_parenthesized_type_variables_with_variance_comma_list__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_parenthesized_class_type_arguments_comma_list__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_object_label_declarations_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_located_attributes_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_functor_parameters_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_loption_class_type_parameters_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_longident_type_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_llist_aux_preceded_COMMA_opt_spread_lbl_expr___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_llist_aux_match_case_seq_expr__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_llist_aux_match_case_expr__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_simple_expr_no_call_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_bar_row_field_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_attributed_ext_constructor_extension_constructor_declaration__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_attributed_ext_constructor_either_extension_constructor_declaration_extension_constructor_rebind___ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_module_rec_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_module_bindings_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_let_binding_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_class_type_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_class_description_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_list_and_class_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_letop_bindings -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_letop_binding_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_let_bindings -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_let_binding_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_let_binding -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_lbl_pattern -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labelled_arrow_type_parameter_optional -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labeled_pattern_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labeled_pattern -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labeled_expr_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labeled_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_labeled_arguments -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_label_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_jsx_without_leading_less -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_jsx_start_tag_and_args_without_leading_less -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_jsx_start_tag_and_args -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_jsx_arguments -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_jsx -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_item_extension_sugar -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_item_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_interface -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_implementation -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_ident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_greater_spread -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_generalized_constructor_arguments -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_functor_parameters -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_fun_def_EQUALGREATER_non_arrowed_core_type_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_fun_def_EQUAL_core_type_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_field_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_extension_constructor_rebind -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_extension_constructor_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_expr_optional_constraint -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_expr_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_expr_comma_seq_extension -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_expr -> default_expr ()
    | MenhirInterpreter.N MenhirInterpreter.N_es6_parameters -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_embedded_private_flag_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_embedded___anonymous_39_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_embedded___anonymous_32_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_embedded___anonymous_1_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_embedded___anonymous_0_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_preceded_EQUALGREATER_expr__braced_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_preceded_EQUAL_expr__braced_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_preceded_EQUAL_class_instance_type__class_type_body_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_preceded_EQUAL_class_expr__class_body_expr_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_parenthesized_longident_type_constraint__longident_type_constraint_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_extension_constructor_declaration_extension_constructor_rebind_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_constructor_declaration_bar_constructor_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either___anonymous_11___anonymous_12_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_either_ES6_FUN_FUN_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_direction_flag -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_core_type2 -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constructor_declarations_aux -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constructor_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constructor_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constructor_arguments_comma_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constructor_arguments -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constrain_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constrain -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constr_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_constant -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_clty_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_type_declarations -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_type_declaration_details -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_type_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_type_arguments_comma_list -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_simple_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_sig_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_sig_body_fields -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_sig_body_cty -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_sig_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_self_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_self_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_longident -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_instance_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_expr_lets_and_rest -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_descriptions -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_description_details -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_declaration_details -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_declaration_body -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_class_constructor_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_braced_expr -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_boption_AMPERSAND_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_basic_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_bar_row_field -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_bar_constructor_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_attributed_ext_constructors_extension_constructor_declaration_ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_attributed_ext_constructors_either_extension_constructor_declaration_extension_constructor_rebind__ -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_attribute -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_attr_id -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_arrowed_simple_core_type -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_arrow_type_parameters -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_arrow_type_parameter -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_type_subst_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_type_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_module_rec_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_module_bindings -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_class_type_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_class_description -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N_and_class_declaration -> raise Not_found
    | MenhirInterpreter.N MenhirInterpreter.N__lbl_pattern_list -> raise Not_found
end

let default_value = Default.value

open MenhirInterpreter

type action =
  | Abort
  | R of int
  | S : 'a symbol -> action
  | Sub of action list

type decision =
  | Nothing
  | One of action list
  | Select of (int -> action list)

let depth =
  [|0;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;2;3;2;2;1;1;2;1;1;1;1;2;3;1;1;1;2;1;2;3;4;1;2;3;4;2;3;5;6;3;4;1;2;3;1;1;1;1;2;3;3;2;1;1;1;1;2;1;1;1;1;1;2;2;3;4;1;1;1;2;1;1;1;1;2;1;1;2;1;1;2;3;4;1;1;2;1;1;2;3;1;1;2;1;1;1;2;1;1;1;1;2;1;1;1;1;1;1;1;1;1;1;1;2;1;2;3;2;3;1;2;1;1;2;1;2;1;1;2;1;2;2;3;1;2;2;3;2;3;1;1;2;3;1;2;1;2;3;2;1;1;2;1;1;1;1;1;1;2;1;2;1;1;2;1;1;1;1;1;1;2;3;2;2;3;1;2;1;2;2;3;1;1;2;1;1;1;1;1;1;2;1;2;2;1;1;2;1;2;3;2;3;4;1;1;2;1;1;3;2;1;2;3;3;1;1;1;3;1;1;2;3;1;1;4;1;1;1;1;5;1;1;1;2;1;1;2;3;1;4;5;1;6;1;1;1;1;2;2;1;2;1;2;1;2;3;1;1;1;1;1;2;3;1;1;1;2;4;5;1;6;1;1;2;1;1;1;2;3;1;2;1;3;1;2;3;1;2;1;1;2;3;4;1;1;1;2;2;2;3;4;3;4;2;3;4;3;1;2;3;1;1;2;3;1;2;3;4;1;1;1;1;2;3;4;2;3;4;1;2;3;1;2;1;2;3;1;2;3;4;2;3;4;3;4;1;1;2;1;3;4;1;2;3;1;2;1;2;3;4;5;1;1;1;1;2;2;3;1;1;2;3;2;1;2;1;1;2;1;1;1;2;3;4;5;1;2;3;4;2;2;3;3;4;2;3;1;2;3;2;1;2;3;1;1;1;2;2;1;2;1;1;2;1;2;3;1;2;3;1;2;1;2;1;2;3;4;1;2;3;4;5;3;4;2;3;1;1;1;2;3;1;2;3;4;5;3;4;4;2;3;2;7;1;1;2;2;1;2;3;1;2;2;3;3;4;1;2;3;1;2;3;1;2;1;1;2;1;1;1;2;3;2;3;2;3;4;2;3;4;2;3;2;3;2;3;3;3;2;2;2;2;3;4;1;1;1;2;3;2;3;1;2;3;1;2;1;2;3;4;5;1;3;2;4;2;1;2;1;1;2;1;3;1;1;2;2;2;2;3;2;3;4;1;5;5;5;6;4;4;4;4;5;5;1;1;1;1;2;3;2;2;1;2;3;3;2;3;3;4;5;6;7;8;9;1;1;2;3;2;1;2;3;1;1;1;1;2;2;1;1;1;2;3;2;3;4;5;6;7;4;5;1;2;3;4;2;3;4;1;3;2;3;1;2;3;3;1;1;2;3;1;1;2;1;4;1;2;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;1;2;1;1;1;1;1;1;2;3;2;3;4;1;2;1;1;1;2;1;2;2;1;2;2;1;1;2;1;3;4;3;1;4;5;1;1;1;1;1;2;3;1;2;3;1;1;2;3;4;5;4;1;2;1;1;1;1;2;1;2;1;1;1;1;3;1;2;3;1;2;3;1;2;3;4;1;1;2;3;1;1;1;1;2;1;1;2;3;2;3;1;2;2;2;3;3;4;1;1;2;2;3;1;2;3;1;2;3;1;2;1;1;2;3;4;5;3;4;5;3;4;4;5;3;4;5;1;2;2;3;4;2;3;2;3;2;3;4;2;2;2;3;2;3;4;5;6;7;8;2;3;1;2;3;1;1;1;4;2;3;1;2;3;4;5;6;2;1;2;3;4;1;2;1;2;2;1;2;3;1;1;1;2;2;1;2;3;2;2;3;1;2;3;1;1;1;1;1;1;2;3;2;1;2;3;1;2;1;2;3;2;3;2;3;4;5;1;2;1;1;2;1;2;1;2;1;3;4;5;1;2;3;4;5;1;1;1;2;2;3;1;3;2;3;4;5;1;2;3;4;1;2;3;1;1;2;2;3;2;1;2;3;2;1;2;3;4;5;6;7;8;1;2;1;1;1;1;1;2;1;2;3;3;4;1;1;2;3;4;2;3;5;6;2;3;2;1;1;2;3;2;3;4;5;1;2;1;1;1;2;1;1;1;2;1;2;1;1;2;1;2;3;1;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;4;3;2;3;2;3;2;3;2;3;4;5;2;2;1;4;5;3;1;2;4;5;1;2;2;3;4;2;3;2;3;2;2;3;4;2;3;4;2;3;4;5;3;4;2;3;5;6;1;3;3;4;5;3;4;4;5;3;4;2;3;5;6;1;3;1;2;2;3;4;4;4;1;2;3;1;2;3;4;4;2;3;4;5;6;5;3;1;1;2;2;4;1;4;5;6;7;8;9;2;3;4;5;6;9;6;7;7;1;2;3;2;1;2;4;5;4;5;1;2;3;4;5;6;7;8;8;5;6;6;2;3;4;4;5;6;7;8;9;10;10;7;8;8;4;3;4;5;6;2;3;4;5;6;7;3;4;5;6;7;8;3;4;5;1;2;3;4;2;3;4;5;3;4;5;6;3;4;3;4;5;6;1;6;1;1;7;8;9;10;1;5;2;1;2;3;1;2;4;1;2;3;4;5;3;4;5;6;7;2;3;4;5;6;1;2;1;2;3;4;5;3;4;2;3;1;5;1;2;3;1;2;2;1;2;3;2;2;3;4;3;4;2;2;3;4;2;3;4;5;6;1;4;1;2;1;2;1;2;3;1;2;1;3;4;5;1;2;1;2;1;2;3;4;5;6;7;8;2;3;1;2;3;1;2;1;3;1;2;3;4;5;1;1;2;3;1;2;4;1;2;3;4;5;3;4;5;6;7;2;3;4;5;6;2;3;1;2;4;5;6;7;8;3;4;5;6;7;2;3;4;2;1;2;3;4;1;1;2;1;2;1;2;3;4;5;6;1;2;3;4;3;1;2;3;4;5;6;7;8;9;10;1;2;3;4;5;5;1;2;6;1;1;1;2;1;3;1;2;3;1;2;3;4;1;2;3;4;1;2;3;1;2;3;1;1;2;1;2;3;4;3;4;5;6;1;1;2;1;2;3;4;5;5;6;1;2;1;1;2;1;2;1;1;1;1;1;2;2;1;2;2;3;3;4;3;1;1;1;2;1;2;2;1;2;3;4;1;1;2;3;4;5;1;2;3;4;5;1;1;1;1;2;3;1;1;1;1;2;2;3;2;1;2;1;2;2;1;1;2;3;2;1;2;1;1;2;3;4;5;1;2;3;2;3;4;5;6;2;3;4;5;6;2;3;2;3;2;1;2;1;3;2;1;1;6;1;1;2;3;3;4;2;3;1;2;4;1;3;1;2;1;2;3;4;1;2;1;2;3;4;1;5;1;2;3;2;1;2;1;2;3;3;1;2;1;1;1;2;1;3;1;1;1;2;3;2;1;1;2;1;2;1;1;2;1;2;3;1;2;3;4;3;1;2;1;2;3;4;2;3;3;2;2;1;1;2;3;4;5;6;7;8;6;4;4;5;6;7;8;9;10;2;3;4;2;3;4;5;2;3;4;5;2;3;2;3;4;5;6;6;7;2;3;2;3;4;5;3;4;2;3;4;3;2;3;4;2;3;4;5;2;1;1;1;2;1;2;1;1;2;3;4;1;2;1;1;1;1;1;1;1;1;2;1;2;1;2;1;3;1;1;2;3;4;1;2;1;5;1;2;3;4;5;6;4;5;6;7;8;3;4;5;6;7;3;1;2;4;1;2;1;1;2;3;4;5;1;1;1;2;3;1;2;3;4;5;6;5;6;7;2;3;4;5;4;5;6;2;3;4;5;2;3;2;3;4;5;2;3;2;2;1;2;3;4;5;2;3;4;5;6;7;8;2;3;4;3;3;1;2;1;1;1;2;3;2;1;1;2;2;3;4;1;1;2;1;1;2;1;2;3;4;3;2;3;1;1;6;2;3;2;3;3;4;5;2;3;1;2;2;5;1;1;4;5;6;5;6;7;8;4;5;6;7;8;9;8;9;10;9;10;11;12;8;9;10;11;7;4;5;6;7;3;2;1;2;1;2;3;3;1;2;1;2;1;2;1;1;2;3;2;3;2;3;4;5;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;2;3;4;3;2;3;2;3;2;3;2;3;1;1;2;3;1;1;1;2;3;4;5;6;2;3;4;5;6;7;3;4;5;6;7;8;3;4;5;1;2;1;1;2;2;3;1;4;2;1;2;1;2;3;1;2;3;4;3;1;2;1;1;1;2;3;4;5;6;7;1;2;3;4;1;2;3;4;5;3;4;2;3;1;1;1;2;3;1;2;3;4;5;3;4;4;2;3;2;8;4;5;6;7;8;9;10;2;3;4;2;3;4;5;6;2;2;3;2;3;4;5;6;6;7;2;3;2;3;4;2;2;3;2;3;4;2;3;1;1;2;1;1;2;1;1;2;3;3;4;2;3;3;1;2;3;1;2;3;2;6;7;8;4;5;3;4;5;3;4;5;3;4;4;5;3;4;5;6;3;4;4;5;4;5;2;3;2;3;2;2;3;2;3;4;4;1;2;3;4;1;1;1;2;1;2;3;4;5;1;2;3;2;3;1;1;2;1;3;1;2;3;4;5;6;1;2;3;4;1;1;2;2;3;4;5;6;7;1;2;3;1;2;2;3;4;1;2;3;1;2;2;4;2;3;1;5;5;6;7;2;2;3;4;5;3;4;5;6;3;1;1;2;3;4;5;6;7;8;4;5;3;4;5;3;4;5;3;4;4;5;3;4;5;6;3;4;4;5;4;5;1;1;1;1;2;3;3;4;4;5;6;2;3;4;2;3;2;2;3;4;4;3;4;2;2;3;2;3;4;2;3;2;3;3;4;4;5;3;4;5;6;7;3;4;1;2;3;2;1;1;2;3;2;3;4;2;3;4;2;3;4;5;2;3;4;5;6;3;4;2;3;1;2;3;1;1;2;3;3;4;1;1;2;1;2;1;2;1;3;3;2;2;2;3;2;3;4;5;5;6;5;4;4;4;5;4;2;3;3;4;5;6;7;3;4;5;6;7;8;9;3;4;3;2;2;3;4;5;6;7;8;2;2;3;2;2;3;2;4;5;3;4;2;3;2;3;4;5;6;7;2;3;2;3;4;5;6;7;2;3;4;5;3;4;5;6;7;8;2;2;3;5;6;2;3;4;2;4;5;4;5;6;2;1;1;2;3;4;5;3;4;5;2;3;2;3;2;3;2;3;1;1;2;3;3;4;2;3;2;3;3;4;1;2;1;0;1;2;1;0;1;1;2;0;1;1;2;0;1;2;1;0;1;2;1;1;1;1;1;1;3;1;1;1;2;1;2;1;0;1;1;1;1;2;3;1;2;3;1;2;2;|]

let can_pop (type a) : a terminal -> bool = function
  | T_WITH -> true
  | T_WHILE -> true
  | T_WHEN -> true
  | T_VIRTUAL -> true
  | T_VAL -> true
  | T_UNDERSCORE -> true
  | T_TYPE -> true
  | T_TRY -> true
  | T_TRUE -> true
  | T_TO -> true
  | T_TILDE -> true
  | T_THEN -> true
  | T_SWITCH -> true
  | T_STRUCT -> true
  | T_STAR -> true
  | T_SLASHGREATER -> true
  | T_SIG -> true
  | T_SHARPEQUAL -> true
  | T_SHARP -> true
  | T_SEMISEMI -> true
  | T_SEMI -> true
  | T_RPAREN -> true
  | T_REC -> true
  | T_RBRACKET -> true
  | T_RBRACE -> true
  | T_QUOTE -> true
  | T_QUESTION -> true
  | T_PUB -> true
  | T_PRI -> true
  | T_PLUSEQ -> true
  | T_PLUSDOT -> true
  | T_PLUS -> true
  | T_PERCENT -> true
  | T_OR -> true
  | T_OPEN -> true
  | T_OF -> true
  | T_OBJECT -> true
  | T_NONREC -> true
  | T_NEW -> true
  | T_MUTABLE -> true
  | T_MODULE -> true
  | T_MINUSGREATER -> true
  | T_MINUSDOT -> true
  | T_MINUS -> true
  | T_LPAREN -> true
  | T_LET -> true
  | T_LESSSLASHGREATER -> true
  | T_LESSGREATER -> true
  | T_LESSDOTDOTGREATER -> true
  | T_LESS -> true
  | T_LBRACKETPERCENTPERCENT -> true
  | T_LBRACKETPERCENT -> true
  | T_LBRACKETLESS -> true
  | T_LBRACKETGREATER -> true
  | T_LBRACKETBAR -> true
  | T_LBRACKETAT -> true
  | T_LBRACKET -> true
  | T_LBRACELESS -> true
  | T_LBRACE -> true
  | T_LAZY -> true
  | T_INITIALIZER -> true
  | T_INHERIT -> true
  | T_INCLUDE -> true
  | T_IN -> true
  | T_IF -> true
  | T_GREATERRBRACE -> true
  | T_GREATERDOTDOTDOT -> true
  | T_GREATER -> true
  | T_FUNCTOR -> true
  | T_FUNCTION -> true
  | T_FUN -> true
  | T_FOR -> true
  | T_FALSE -> true
  | T_EXTERNAL -> true
  | T_EXCEPTION -> true
  | T_ES6_FUN -> true
  | T_EQUALGREATER -> true
  | T_EQUAL -> true
  | T_EOL -> true
  | T_END -> true
  | T_ELSE -> true
  | T_DOWNTO -> true
  | T_DOTDOTDOT -> true
  | T_DOTDOT -> true
  | T_DOT -> true
  | T_DONE -> true
  | T_DO -> true
  | T_CONSTRAINT -> true
  | T_COMMA -> true
  | T_COLONGREATER -> true
  | T_COLONEQUAL -> true
  | T_COLONCOLON -> true
  | T_COLON -> true
  | T_CLASS -> true
  | T_BEGIN -> true
  | T_BARRBRACKET -> true
  | T_BARBAR -> true
  | T_BAR -> true
  | T_BANG -> true
  | T_BACKQUOTE -> true
  | T_ASSERT -> true
  | T_AS -> true
  | T_AND -> true
  | T_AMPERSAND -> true
  | T_AMPERAMPER -> true
  | _ -> false

let recover =
  let r0 = Sub [S (T T_RPAREN); R 688] in
  let r1 = Sub [S (T T_DOT); r0] in
  let r2 = Sub [S (T T_LPAREN); r1] in
  let r3 = Sub [S (N N_simple_expr_call); R 1131] in
  let r4 = Sub [r2; r3] in
  let r5 = Sub [S (T T_WITH); R 999; R 34] in
  let r6 = Sub [S (N N_simple_expr_call); R 242] in
  let r7 = Sub [r2; r6] in
  let r8 = Sub [S (N N_seq_expr_no_seq); R 752] in
  let r9 = Sub [S (T T_RBRACE); R 59] in
  let r10 = Sub [S (N N_expr); R 1180] in
  let r11 = Sub [S (T T_EQUAL); r10] in
  let r12 = Sub [S (T T_LIDENT); r11] in
  let r13 = Sub [R 546; r12] in
  let r14 = Sub [R 684; r13] in
  let r15 = Sub [S (T T_UNDERSCORE); R 50] in
  let r16 = Sub [r15; R 554] in
  let r17 = Sub [r16; R 1120] in
  let r18 = Sub [r17; R 182] in
  let r19 = Sub [r18; R 180] in
  let r20 = Sub [r19; R 1178] in
  let r21 = Sub [S (T T_COLON); r20] in
  let r22 = Sub [S (T T_LIDENT); r21] in
  let r23 = Sub [S (T T_UIDENT); R 501] in
  let r24 = Sub [r23; R 448] in
  let r25 = Sub [S (T T_RPAREN); R 492] in
  let r26 = Sub [r24; r25] in
  let r27 = Sub [S (T T_UIDENT); R 502] in
  let r28 = Sub [S (T T_RPAREN); R 493] in
  let r29 = Sub [S (T T_RPAREN); R 494] in
  let r30 = Sub [r19; R 720] in
  let r31 = Sub [R 680; R 363] in
  let r32 = Sub [S (T T_EQUAL); r31] in
  let r33 = Sub [r30; r32] in
  let r34 = Sub [S (T T_COLON); r33] in
  let r35 = Sub [S (T T_LIDENT); R 111] in
  let r36 = Sub [S (T T_LIDENT); R 112] in
  let r37 = Sub [r30; R 466] in
  let r38 = Sub [S (T T_RPAREN); R 1081] in
  let r39 = Sub [R 642; r38] in
  let r40 = Sub [S (T T_LIDENT); R 317] in
  let r41 = Sub [r40; R 48] in
  let r42 = Sub [S (T T_RBRACE); R 543] in
  let r43 = Sub [R 770; r42] in
  let r44 = Sub [S (T T_LBRACE); r43] in
  let r45 = Sub [r44; R 919] in
  let r46 = Sub [r45; R 536] in
  let r47 = Sub [r46; R 686] in
  let r48 = Sub [S (T T_RPAREN); R 532] in
  let r49 = Sub [S (T T_RPAREN); R 918] in
  let r50 = Sub [S (T T_LPAREN); r48; r49] in
  let r51 = Sub [S (T T_RPAREN); R 524] in
  let r52 = Sub [S (T T_LPAREN); r51] in
  let r53 = Sub [S (T T_RPAREN); R 922] in
  let r54 = Sub [r52; r53] in
  let r55 = Sub [S (T T_OF); r54] in
  let r56 = Sub [S (T T_UNDERSCORE); R 930; R 924] in
  let r57 = Sub [r56; R 701] in
  let r58 = Sub [r57; R 693] in
  let r59 = Sub [r8; R 487] in
  let r60 = Sub [S (T T_EQUALGREATER); r59] in
  let r61 = Sub [R 676; r60] in
  let r62 = Sub [r58; r61] in
  let r63 = Sub [S (T T_BAR); r62] in
  let r64 = Sub [S (T T_RBRACE); R 239] in
  let r65 = Sub [R 410; r64] in
  let r66 = Sub [r63; r65] in
  let r67 = Sub [S (T T_LBRACE); r66] in
  let r68 = Sub [S (N N_simple_expr_no_constructor); r67] in
  let r69 = Sub [S (T T_RPAREN); R 1173] in
  let r70 = Sub [S (T T_LESSDOTDOTGREATER); R 632; r69] in
  let r71 = Sub [S (T T_RBRACE); R 238] in
  let r72 = Sub [R 410; r71] in
  let r73 = Sub [r63; r72] in
  let r74 = Sub [S (T T_LBRACE); r73] in
  let r75 = Sub [S (N N_simple_expr_no_constructor); r74] in
  let r76 = Sub [S (T T_RPAREN); R 495] in
  let r77 = Sub [R 326; R 328] in
  let r78 = Sub [R 326; R 329] in
  let r79 = Sub [R 326; R 327] in
  let r80 = Sub [S (T T_LESSSLASHGREATER); R 322] in
  let r81 = Sub [S (N N_expr); R 277] in
  let r82 = Sub [R 326; R 333] in
  let r83 = Sub [R 1013; R 710] in
  let r84 = Sub [S (T T_RBRACKET); R 286] in
  let r85 = Sub [r83; r84] in
  let r86 = Sub [R 426; R 1114] in
  let r87 = Sub [R 21; R 1060] in
  let r88 = Sub [R 1066; r87] in
  let r89 = Sub [r88; R 1055] in
  let r90 = Sub [r86; r89] in
  let r91 = Sub [S (T T_LIDENT); r90] in
  let r92 = Sub [r91; R 1062] in
  let r93 = Sub [R 586; r92] in
  let r94 = Sub [r88; R 1054] in
  let r95 = Sub [r86; r94] in
  let r96 = Sub [R 642; R 1116] in
  let r97 = Sub [S (T T_UNDERSCORE); R 213; R 1113; R 476; r96] in
  let r98 = Sub [S (T T_RPAREN); R 427] in
  let r99 = Sub [r97; r98] in
  let r100 = Sub [S (T T_GREATER); R 1115] in
  let r101 = Sub [R 664; R 313] in
  let r102 = Sub [R 658; r101] in
  let r103 = Sub [r102; R 163] in
  let r104 = Sub [S (T T_GREATER); R 1083] in
  let r105 = Sub [R 642; r104] in
  let r106 = Sub [S (T T_GREATER); R 1082] in
  let r107 = Sub [R 642; r106] in
  let r108 = Sub [r16; R 551] in
  let r109 = Sub [r108; R 747] in
  let r110 = Sub [R 404; R 748] in
  let r111 = Sub [r109; r110] in
  let r112 = Sub [S (T T_RBRACKET); R 55] in
  let r113 = Sub [R 428; r112] in
  let r114 = Sub [S (T T_RBRACKET); R 54] in
  let r115 = Sub [S (T T_RBRACKET); R 36] in
  let r116 = Sub [r83; r115] in
  let r117 = Sub [S (T T_RBRACE); R 1128] in
  let r118 = Sub [R 410; r117] in
  let r119 = Sub [r63; r118] in
  let r120 = Sub [S (T T_LBRACE); r119] in
  let r121 = Sub [S (N N_simple_expr_no_constructor); r120] in
  let r122 = Sub [S (T T_LESSSLASHGREATER); R 338] in
  let r123 = Sub [R 406; r122] in
  let r124 = Sub [S (T T_GREATER); r123] in
  let r125 = Sub [S (T T_RBRACKET); R 845] in
  let r126 = Sub [S (T T_BARRBRACKET); R 855] in
  let r127 = Sub [S (N N_expr); R 284] in
  let r128 = Sub [r127; R 456] in
  let r129 = Sub [S (T T_BARRBRACKET); R 813] in
  let r130 = Sub [S (T T_BARRBRACKET); R 814] in
  let r131 = Sub [R 642; R 282] in
  let r132 = Sub [S (T T_RBRACKET); R 841] in
  let r133 = Sub [S (T T_RPAREN); R 849] in
  let r134 = Sub [S (T T_RBRACE); R 531] in
  let r135 = Sub [S (T T_RBRACE); R 1127] in
  let r136 = Sub [R 410; r135] in
  let r137 = Sub [r63; r136] in
  let r138 = Sub [S (T T_LBRACE); r137] in
  let r139 = Sub [S (N N_simple_expr_no_constructor); r138] in
  let r140 = Sub [S (T T_BARRBRACKET); R 887] in
  let r141 = Sub [S (T T_BARRBRACKET); R 888] in
  let r142 = Sub [S (T T_RBRACKET); R 152] in
  let r143 = Sub [S (T T_RBRACE); R 863] in
  let r144 = Sub [S (T T_LBRACE); r143] in
  let r145 = Sub [S (T T_RPAREN); R 880] in
  let r146 = Sub [r47; r145] in
  let r147 = Sub [S (T T_COLON); r146] in
  let r148 = Sub [S (T T_RPAREN); R 509] in
  let r149 = Sub [r102; R 292] in
  let r150 = Sub [S (T T_TRUE); r149] in
  let r151 = Sub [R 399; R 40] in
  let r152 = Sub [r150; r151] in
  let r153 = Sub [r152; R 766] in
  let r154 = Sub [r102; R 287] in
  let r155 = Sub [r19; R 438] in
  let r156 = Sub [R 642; R 162] in
  let r157 = Sub [S (T T_RPAREN); R 161] in
  let r158 = Sub [r155; r156; r157] in
  let r159 = Sub [S (T T_RBRACKET); R 53] in
  let r160 = Sub [S (T T_RBRACE); R 599] in
  let r161 = Sub [S (T T_RBRACE); R 603] in
  let r162 = Sub [r19; R 716] in
  let r163 = Sub [r162; R 1010] in
  let r164 = Sub [r40; R 564] in
  let r165 = Sub [r30; R 27] in
  let r166 = Sub [r165; R 478] in
  let r167 = Sub [S (T T_RPAREN); R 30] in
  let r168 = Sub [R 642; r167] in
  let r169 = Sub [R 644; r166; r168] in
  let r170 = Sub [r18; R 31] in
  let r171 = Sub [S (T T_EQUALGREATER); r170] in
  let r172 = Sub [r30; R 28] in
  let r173 = Sub [S (T T_COLON); r172] in
  let r174 = Sub [r17; R 183] in
  let r175 = Sub [S (T T_LIDENT); R 1065] in
  let r176 = Sub [r18; R 32] in
  let r177 = Sub [r40; R 181] in
  let r178 = Sub [r19; R 717] in
  let r179 = Sub [S (T T_LIDENT); R 594] in
  let r180 = Sub [r162; R 1011] in
  let r181 = Sub [S (T T_COLON); r180] in
  let r182 = Sub [S (T T_RBRACE); R 602] in
  let r183 = Sub [S (T T_LESSIDENT); r105; R 555; R 750] in
  let r184 = Sub [r40; R 1048] in
  let r185 = Sub [S (T T_BACKQUOTE); r184] in
  let r186 = Sub [r109; R 45] in
  let r187 = Sub [S (T T_LIDENT); R 743] in
  let r188 = Sub [S (T T_LIDENT); R 742] in
  let r189 = Sub [S (T T_RBRACE); R 723] in
  let r190 = Sub [R 642; r189] in
  let r191 = Sub [r102; R 289] in
  let r192 = Sub [S (T T_RPAREN); r191] in
  let r193 = Sub [r102; R 288] in
  let r194 = Sub [S (T T_RBRACKET); r193] in
  let r195 = Sub [r102; R 291] in
  let r196 = Sub [r102; R 290] in
  let r197 = Sub [r150; R 576] in
  let r198 = Sub [R 399; R 400] in
  let r199 = Sub [R 399; R 401] in
  let r200 = Sub [R 399; R 402] in
  let r201 = Sub [r150; r200] in
  let r202 = Sub [R 399; R 403] in
  let r203 = Sub [S (T T_DOTDOT); R 1105] in
  let r204 = Sub [r102; R 168] in
  let r205 = Sub [r102; R 165] in
  let r206 = Sub [S (T T_RPAREN); r205] in
  let r207 = Sub [r102; R 164] in
  let r208 = Sub [S (T T_RBRACKET); r207] in
  let r209 = Sub [S (T T_TRUE); r204] in
  let r210 = Sub [r102; R 172] in
  let r211 = Sub [S (T T_COLONCOLON); r210] in
  let r212 = Sub [r102; R 169] in
  let r213 = Sub [r102; R 171] in
  let r214 = Sub [S (T T_RPAREN); r213] in
  let r215 = Sub [r102; R 170] in
  let r216 = Sub [S (T T_RBRACKET); r215] in
  let r217 = Sub [r209; R 43] in
  let r218 = Sub [R 24; R 1089] in
  let r219 = Sub [r218; R 1087] in
  let r220 = Sub [r19; R 156] in
  let r221 = Sub [S (T T_EQUAL); r220] in
  let r222 = Sub [R 24; R 1097] in
  let r223 = Sub [S (T T_COLONEQUAL); r203; r222] in
  let r224 = Sub [r223; R 25] in
  let r225 = Sub [r86; r224] in
  let r226 = Sub [r223; R 26] in
  let r227 = Sub [r86; r226] in
  let r228 = Sub [S (T T_LIDENT); r227] in
  let r229 = Sub [S (T T_BAR); r217] in
  let r230 = Sub [R 546; r188; R 468; r190] in
  let r231 = Sub [r91; R 23] in
  let r232 = Sub [r152; R 767] in
  let r233 = Sub [R 225; r232] in
  let r234 = Sub [S (T T_PLUSEQ); r233] in
  let r235 = Sub [r86; r234] in
  let r236 = Sub [S (T T_LIDENT); r235] in
  let r237 = Sub [S (T T_UIDENT); R 506] in
  let r238 = Sub [r237; R 606] in
  let r239 = Sub [S (T T_UIDENT); R 507] in
  let r240 = Sub [r40; R 791] in
  let r241 = Sub [r23; R 1189] in
  let r242 = Sub [S (T T_COLONEQUAL); r241] in
  let r243 = Sub [S (T T_UIDENT); r242] in
  let r244 = Sub [S (T T_MODULE); r243] in
  let r245 = Sub [S (T T_LIDENT); R 342] in
  let r246 = Sub [r19; R 1187] in
  let r247 = Sub [S (T T_COLONEQUAL); r246] in
  let r248 = Sub [r86; r247] in
  let r249 = Sub [S (T T_LIDENT); R 343] in
  let r250 = Sub [r19; R 1185] in
  let r251 = Sub [r23; R 1188] in
  let r252 = Sub [r40; R 545] in
  let r253 = Sub [r46; R 538] in
  let r254 = Sub [r19; R 773] in
  let r255 = Sub [S (T T_COLON); r254] in
  let r256 = Sub [S (T T_RBRACKET); R 320] in
  let r257 = Sub [r83; r256] in
  let r258 = Sub [S (T T_UNDERSCORE); R 505] in
  let r259 = Sub [S (T T_RPAREN); R 938] in
  let r260 = Sub [r47; R 700] in
  let r261 = Sub [R 650; r260] in
  let r262 = Sub [S (T T_BARRBRACKET); R 943] in
  let r263 = Sub [r58; R 462] in
  let r264 = Sub [S (T T_RBRACKET); R 942] in
  let r265 = Sub [R 642; R 695] in
  let r266 = Sub [r245; R 365; R 7] in
  let r267 = Sub [R 646; r266] in
  let r268 = Sub [S (T T_RBRACE); R 941] in
  let r269 = Sub [r40; R 935] in
  let r270 = Sub [S (T T_PLUS); S (T T_FLOAT); R 808] in
  let r271 = Sub [S (T T_RBRACKET); R 948] in
  let r272 = Sub [S (T T_LBRACKET); r271] in
  let r273 = Sub [r58; R 698] in
  let r274 = Sub [S (T T_RPAREN); R 697] in
  let r275 = Sub [R 642; r274] in
  let r276 = Sub [S (T T_COLON); r261] in
  let r277 = Sub [S (T T_BARRBRACKET); R 928] in
  let r278 = Sub [R 646; r263; r265] in
  let r279 = Sub [S (T T_RBRACKET); R 927] in
  let r280 = Sub [S (T T_RBRACE); R 926] in
  let r281 = Sub [S (T T_LIDENT); R 1172] in
  let r282 = Sub [S (T T_BARRBRACKET); R 946] in
  let r283 = Sub [S (T T_RBRACE); R 944] in
  let r284 = Sub [S (T T_RPAREN); R 937] in
  let r285 = Sub [S (T T_RPAREN); R 706] in
  let r286 = Sub [r57; r285] in
  let r287 = Sub [S (T T_COMMA); r286] in
  let r288 = Sub [r57; r287] in
  let r289 = Sub [S (T T_LPAREN); r288] in
  let r290 = Sub [S (N N_simple_expr_call); R 240] in
  let r291 = Sub [r2; r290] in
  let r292 = Sub [S (T T_RPAREN); R 496] in
  let r293 = Sub [S (T T_RPAREN); R 497] in
  let r294 = Sub [S (T T_LESSSLASHIDENTGREATER); R 324] in
  let r295 = Sub [S (T T_RPAREN); R 345] in
  let r296 = Sub [S (T T_UNDERSCORE); R 353] in
  let r297 = Sub [S (T T_QUESTION); R 350] in
  let r298 = Sub [R 674; R 1051] in
  let r299 = Sub [r19; r298] in
  let r300 = Sub [r281; R 1175] in
  let r301 = Sub [S (T T_UNDERSCORE); R 352] in
  let r302 = Sub [S (N N_expr); R 202] in
  let r303 = Sub [S (T T_EQUALGREATER); r302] in
  let r304 = Sub [r303; R 305] in
  let r305 = Sub [R 668; r304] in
  let r306 = Sub [S (T T_RPAREN); r305] in
  let r307 = Sub [S (T T_LPAREN); r306] in
  let r308 = Sub [r307; R 234] in
  let r309 = Sub [R 664; R 362; R 356] in
  let r310 = Sub [S (T T_DOWNTO); R 185] in
  let r311 = Sub [S (N N_simple_expr_call); R 243] in
  let r312 = Sub [S (T T_RPAREN); r311] in
  let r313 = Sub [S (N N_expr); r312] in
  let r314 = Sub [r310; r313] in
  let r315 = Sub [S (N N_expr); r314] in
  let r316 = Sub [S (T T_IN); r315] in
  let r317 = Sub [r58; r316] in
  let r318 = Sub [S (T T_LPAREN); r317] in
  let r319 = Sub [S (T T_UNDERSCORE); R 231] in
  let r320 = Sub [S (N N_expr); R 235] in
  let r321 = Sub [S (T T_EQUALGREATER); r320] in
  let r322 = Sub [S (T T_RPAREN); R 230] in
  let r323 = Sub [S (T T_RPAREN); R 228] in
  let r324 = Sub [S (T T_RBRACKET); R 822] in
  let r325 = Sub [S (N N_expr); r324] in
  let r326 = Sub [S (T T_RBRACE); R 821] in
  let r327 = Sub [S (T T_LBRACE); r326] in
  let r328 = Sub [S (T T_RPAREN); R 838] in
  let r329 = Sub [r47; r328] in
  let r330 = Sub [S (T T_COLON); r329] in
  let r331 = Sub [S (T T_RPAREN); R 309] in
  let r332 = Sub [r52; R 526] in
  let r333 = Sub [S (T T_EQUALGREATER); r332] in
  let r334 = Sub [R 672; r333] in
  let r335 = Sub [r46; R 533] in
  let r336 = Sub [S (T T_RPAREN); R 312] in
  let r337 = Sub [S (N N_expr); R 281] in
  let r338 = Sub [R 642; R 283] in
  let r339 = Sub [S (N N_expr); R 280] in
  let r340 = Sub [S (T T_COLON); r339] in
  let r341 = Sub [S (T T_RBRACKET); R 828] in
  let r342 = Sub [S (T T_LESSSLASHIDENTGREATER); R 340] in
  let r343 = Sub [S (T T_LESSSLASHIDENTGREATER); R 341] in
  let r344 = Sub [S (T T_RBRACKET); R 864] in
  let r345 = Sub [S (N N_expr); r344] in
  let r346 = Sub [S (T T_RBRACKET); R 865] in
  let r347 = Sub [S (N N_expr); r346] in
  let r348 = Sub [S (N N_expr); R 440] in
  let r349 = Sub [S (T T_RBRACE); R 866] in
  let r350 = Sub [R 642; r349] in
  let r351 = Sub [r127; R 442; r338] in
  let r352 = Sub [S (T T_BARRBRACKET); R 827] in
  let r353 = Sub [S (T T_LIDENT); R 300; R 444] in
  let r354 = Sub [S (T T_GREATERRBRACE); R 833] in
  let r355 = Sub [R 642; r354] in
  let r356 = Sub [R 642; R 740] in
  let r357 = Sub [S (N N_expr); r356] in
  let r358 = Sub [S (T T_COLON); r357] in
  let r359 = Sub [R 642; R 725] in
  let r360 = Sub [R 412; r359] in
  let r361 = Sub [r245; r360] in
  let r362 = Sub [R 646; r361] in
  let r363 = Sub [S (T T_COMMA); r362] in
  let r364 = Sub [r245; R 459] in
  let r365 = Sub [R 642; R 726] in
  let r366 = Sub [R 666; R 1006] in
  let r367 = Sub [R 642; R 724] in
  let r368 = Sub [R 412; r367] in
  let r369 = Sub [R 642; R 1009] in
  let r370 = Sub [R 642; R 729] in
  let r371 = Sub [S (N N_expr); r370] in
  let r372 = Sub [R 642; R 734] in
  let r373 = Sub [R 412; r372] in
  let r374 = Sub [r245; r373] in
  let r375 = Sub [R 642; R 733] in
  let r376 = Sub [R 412; r375] in
  let r377 = Sub [R 642; R 732] in
  let r378 = Sub [R 412; r377] in
  let r379 = Sub [R 642; R 731] in
  let r380 = Sub [R 412; r379] in
  let r381 = Sub [S (T T_RBRACKET); R 823] in
  let r382 = Sub [S (N N_expr); r381] in
  let r383 = Sub [S (T T_LBRACKET); r382] in
  let r384 = Sub [S (T T_RBRACE); R 824] in
  let r385 = Sub [R 642; r384] in
  let r386 = Sub [r348; r385] in
  let r387 = Sub [S (N N_expr); R 236] in
  let r388 = Sub [S (T T_EQUALGREATER); r387] in
  let r389 = Sub [r303; R 307] in
  let r390 = Sub [R 668; r389] in
  let r391 = Sub [r303; R 308] in
  let r392 = Sub [R 668; r391] in
  let r393 = Sub [S (T T_RPAREN); r392] in
  let r394 = Sub [r303; R 306] in
  let r395 = Sub [R 668; r394] in
  let r396 = Sub [S (T T_RPAREN); r395] in
  let r397 = Sub [S (N N_expr); R 486] in
  let r398 = Sub [S (T T_EQUALGREATER); r397] in
  let r399 = Sub [R 676; r398] in
  let r400 = Sub [S (T T_RPAREN); R 346] in
  let r401 = Sub [S (T T_LESSSLASHIDENTGREATER); R 325] in
  let r402 = Sub [r52; R 604] in
  let r403 = Sub [r40; R 1031] in
  let r404 = Sub [R 652; r403] in
  let r405 = Sub [S (T T_RPAREN); R 1133] in
  let r406 = Sub [S (N N_expr); r405] in
  let r407 = Sub [S (T T_COMMA); r406] in
  let r408 = Sub [S (N N_expr); r407] in
  let r409 = Sub [S (T T_LPAREN); r408] in
  let r410 = Sub [S (T T_RPAREN); r409] in
  let r411 = Sub [S (N N_expr); R 1166] in
  let r412 = Sub [S (T T_MODULE); R 637] in
  let r413 = Sub [S (N N_expr); R 373] in
  let r414 = Sub [S (T T_EQUAL); r413] in
  let r415 = Sub [r58; r414] in
  let r416 = Sub [r415; R 367] in
  let r417 = Sub [S (N N_expr); R 374] in
  let r418 = Sub [S (T T_EQUAL); r417] in
  let r419 = Sub [S (N N_expr); R 200] in
  let r420 = Sub [S (T T_EQUAL); r419] in
  let r421 = Sub [r420; R 301] in
  let r422 = Sub [R 664; r421] in
  let r423 = Sub [r420; R 303] in
  let r424 = Sub [R 664; r423] in
  let r425 = Sub [r420; R 304] in
  let r426 = Sub [R 664; r425] in
  let r427 = Sub [S (T T_RPAREN); r426] in
  let r428 = Sub [r420; R 302] in
  let r429 = Sub [R 664; r428] in
  let r430 = Sub [S (T T_RPAREN); r429] in
  let r431 = Sub [S (T T_LIDENT); R 560] in
  let r432 = Sub [S (N N_expr); R 372] in
  let r433 = Sub [S (T T_EQUAL); r432] in
  let r434 = Sub [r19; r433] in
  let r435 = Sub [S (T T_DOT); r434] in
  let r436 = Sub [S (N N_expr); R 371] in
  let r437 = Sub [S (T T_EQUAL); r436] in
  let r438 = Sub [r19; r437] in
  let r439 = Sub [S (N N_expr); R 369] in
  let r440 = Sub [S (N N_simple_expr_call); R 1129] in
  let r441 = Sub [r2; r440] in
  let r442 = Sub [r307; R 1123] in
  let r443 = Sub [S (N N_simple_expr_call); R 1132] in
  let r444 = Sub [S (T T_RPAREN); r443] in
  let r445 = Sub [S (N N_expr); r444] in
  let r446 = Sub [r310; r445] in
  let r447 = Sub [S (N N_expr); r446] in
  let r448 = Sub [S (T T_IN); r447] in
  let r449 = Sub [r58; r448] in
  let r450 = Sub [S (T T_LPAREN); r449] in
  let r451 = Sub [S (T T_SEMI); R 1022] in
  let r452 = Sub [r19; r451] in
  let r453 = Sub [S (T T_COLON); r452] in
  let r454 = Sub [S (T T_STRING); R 558; R 718] in
  let r455 = Sub [S (T T_TRUE); R 155] in
  let r456 = Sub [r455; R 298] in
  let r457 = Sub [S (T T_TRUE); S (T T_EQUAL); r456; R 193] in
  let r458 = Sub [S (T T_RPAREN); R 153] in
  let r459 = Sub [S (N N_expr); R 1124] in
  let r460 = Sub [S (T T_EQUALGREATER); r459] in
  let r461 = Sub [S (N N_expr); R 1125] in
  let r462 = Sub [S (T T_EQUALGREATER); r461] in
  let r463 = Sub [S (T T_SEMI); R 777] in
  let r464 = Sub [r19; r463] in
  let r465 = Sub [S (T T_COLON); r464] in
  let r466 = Sub [R 654; R 120] in
  let r467 = Sub [r466; R 117; R 118] in
  let r468 = Sub [S (T T_RBRACE); R 140] in
  let r469 = Sub [r467; r468] in
  let r470 = Sub [S (T T_LBRACE); r469; R 199; R 142] in
  let r471 = Sub [R 416; r470] in
  let r472 = Sub [S (T T_LIDENT); r471] in
  let r473 = Sub [R 1183; r472] in
  let r474 = Sub [R 385; R 143] in
  let r475 = Sub [r473; r474] in
  let r476 = Sub [r40; R 1112] in
  let r477 = Sub [S (T T_QUOTE); r476; R 1080] in
  let r478 = Sub [S (T T_RPAREN); R 417] in
  let r479 = Sub [R 642; r478] in
  let r480 = Sub [r19; R 1182] in
  let r481 = Sub [S (T T_COLON); r480] in
  let r482 = Sub [S (T T_LIDENT); r481] in
  let r483 = Sub [R 548; r482] in
  let r484 = Sub [r162; R 128] in
  let r485 = Sub [S (T T_COLON); r484] in
  let r486 = Sub [S (T T_LIDENT); r485] in
  let r487 = Sub [r162; R 126] in
  let r488 = Sub [S (T T_COLON); r487] in
  let r489 = Sub [S (T T_LIDENT); r488] in
  let r490 = Sub [R 424; R 107] in
  let r491 = Sub [S (T T_LIDENT); R 145; r490] in
  let r492 = Sub [S (T T_LIDENT); R 146] in
  let r493 = Sub [R 642; R 139] in
  let r494 = Sub [S (T T_RPAREN); R 425] in
  let r495 = Sub [S (T T_RBRACE); R 141] in
  let r496 = Sub [r19; R 157] in
  let r497 = Sub [S (T T_EQUAL); r496] in
  let r498 = Sub [r19; r497] in
  let r499 = Sub [r467; R 119] in
  let r500 = Sub [S (T T_SEMI); r499] in
  let r501 = Sub [r237; r500] in
  let r502 = Sub [R 684; r501] in
  let r503 = Sub [r162; R 129] in
  let r504 = Sub [S (T T_COLON); r503] in
  let r505 = Sub [S (T T_LIDENT); r504] in
  let r506 = Sub [r162; R 127] in
  let r507 = Sub [S (T T_COLON); r506] in
  let r508 = Sub [S (T T_LIDENT); r507] in
  let r509 = Sub [r473; R 16] in
  let r510 = Sub [r491; R 65] in
  let r511 = Sub [r510; R 78] in
  let r512 = Sub [S (T T_COLON); r511] in
  let r513 = Sub [R 416; r512] in
  let r514 = Sub [S (T T_LIDENT); r513] in
  let r515 = Sub [r510; R 66] in
  let r516 = Sub [R 383; R 79] in
  let r517 = Sub [R 1183; r514] in
  let r518 = Sub [r517; R 14] in
  let r519 = Sub [r237; R 785] in
  let r520 = Sub [r44; R 540] in
  let r521 = Sub [R 392; R 789] in
  let r522 = Sub [r520; R 19] in
  let r523 = Sub [r520; R 20] in
  let r524 = Sub [r258; r523] in
  let r525 = Sub [r23; R 787] in
  let r526 = Sub [r91; R 1063] in
  let r527 = Sub [R 586; r526] in
  let r528 = Sub [r152; R 768] in
  let r529 = Sub [r152; R 769] in
  let r530 = Sub [R 225; r529] in
  let r531 = Sub [S (T T_PLUSEQ); r530] in
  let r532 = Sub [r86; r531] in
  let r533 = Sub [S (T T_LIDENT); r532] in
  let r534 = Sub [r237; R 607] in
  let r535 = Sub [r40; R 792] in
  let r536 = Sub [r19; R 774] in
  let r537 = Sub [S (T T_SEMI); R 778] in
  let r538 = Sub [r19; r537] in
  let r539 = Sub [S (T T_COLON); r538] in
  let r540 = Sub [R 385; R 144] in
  let r541 = Sub [r473; r540] in
  let r542 = Sub [R 383; R 80] in
  let r543 = Sub [r237; R 786] in
  let r544 = Sub [R 392; R 790] in
  let r545 = Sub [r258; R 640] in
  let r546 = Sub [r23; R 788] in
  let r547 = Sub [R 654; R 591] in
  let r548 = Sub [r547; R 590; R 92] in
  let r549 = Sub [S (T T_RBRACE); R 197] in
  let r550 = Sub [r548; r549] in
  let r551 = Sub [S (T T_LBRACE); r550; R 67] in
  let r552 = Sub [R 662; r551] in
  let r553 = Sub [r552; R 68] in
  let r554 = Sub [S (T T_LIDENT); r553] in
  let r555 = Sub [R 1183; r554] in
  let r556 = Sub [R 381; R 1036] in
  let r557 = Sub [r552; R 69] in
  let r558 = Sub [r35; R 135; R 81] in
  let r559 = Sub [S (T T_RPAREN); R 138] in
  let r560 = Sub [S (T T_RBRACE); R 136] in
  let r561 = Sub [R 656; R 94] in
  let r562 = Sub [r558; r561] in
  let r563 = Sub [R 434; R 88] in
  let r564 = Sub [r558; R 82] in
  let r565 = Sub [S (T T_EQUALGREATER); r564] in
  let r566 = Sub [S (T T_RPAREN); r565] in
  let r567 = Sub [r558; R 84] in
  let r568 = Sub [S (T T_EQUALGREATER); r567] in
  let r569 = Sub [r558; R 85] in
  let r570 = Sub [S (T T_EQUALGREATER); r569] in
  let r571 = Sub [S (T T_RPAREN); r570] in
  let r572 = Sub [r558; R 83] in
  let r573 = Sub [S (T T_EQUALGREATER); r572] in
  let r574 = Sub [S (T T_RPAREN); r573] in
  let r575 = Sub [r548; R 93] in
  let r576 = Sub [S (T T_SEMI); r575] in
  let r577 = Sub [r237; r576] in
  let r578 = Sub [R 684; r577] in
  let r579 = Sub [r19; R 1176] in
  let r580 = Sub [S (T T_COLON); r579] in
  let r581 = Sub [S (N N_expr); R 1177] in
  let r582 = Sub [S (N N_expr); R 1181] in
  let r583 = Sub [r415; R 368] in
  let r584 = Sub [R 721; r583] in
  let r585 = Sub [R 660; r584] in
  let r586 = Sub [R 656; R 95] in
  let r587 = Sub [r558; r586] in
  let r588 = Sub [r420; R 490] in
  let r589 = Sub [R 670; r588] in
  let r590 = Sub [S (T T_LIDENT); r589] in
  let r591 = Sub [R 684; r590] in
  let r592 = Sub [r162; R 488] in
  let r593 = Sub [S (T T_COLON); r592] in
  let r594 = Sub [r420; R 491] in
  let r595 = Sub [r19; r594] in
  let r596 = Sub [S (T T_DOT); r595] in
  let r597 = Sub [r58; R 113] in
  let r598 = Sub [r548; R 91] in
  let r599 = Sub [R 387; R 388] in
  let r600 = Sub [R 387; R 389] in
  let r601 = Sub [r415; r600] in
  let r602 = Sub [S (T T_RPAREN); R 137] in
  let r603 = Sub [r552; R 71] in
  let r604 = Sub [r552; R 72] in
  let r605 = Sub [S (T T_RPAREN); r604] in
  let r606 = Sub [r552; R 73] in
  let r607 = Sub [S (T T_RPAREN); r606] in
  let r608 = Sub [r552; R 74] in
  let r609 = Sub [r552; R 76] in
  let r610 = Sub [r552; R 77] in
  let r611 = Sub [S (T T_RPAREN); r610] in
  let r612 = Sub [r552; R 75] in
  let r613 = Sub [S (T T_RPAREN); r612] in
  let r614 = Sub [r552; R 70] in
  let r615 = Sub [S (T T_RPAREN); r614] in
  let r616 = Sub [r555; R 12] in
  let r617 = Sub [S (N N_expr); R 1169] in
  let r618 = Sub [S (T T_COLON); r617] in
  let r619 = Sub [S (N N_expr); R 1163] in
  let r620 = Sub [S (N N_expr); R 1164] in
  let r621 = Sub [S (N N_expr); R 1165] in
  let r622 = Sub [S (N N_expr); R 1162] in
  let r623 = Sub [r52; R 529] in
  let r624 = Sub [S (T T_EQUAL); r623] in
  let r625 = Sub [r624; R 512] in
  let r626 = Sub [R 418; r625] in
  let r627 = Sub [r624; R 513] in
  let r628 = Sub [R 390; R 1029] in
  let r629 = Sub [r626; R 17] in
  let r630 = Sub [r626; R 18] in
  let r631 = Sub [r258; r630] in
  let r632 = Sub [R 394; R 38] in
  let r633 = Sub [r457; r632] in
  let r634 = Sub [r633; R 1004] in
  let r635 = Sub [r457; R 568] in
  let r636 = Sub [R 394; R 395] in
  let r637 = Sub [R 394; R 396] in
  let r638 = Sub [R 394; R 397] in
  let r639 = Sub [r457; r638] in
  let r640 = Sub [R 394; R 398] in
  let r641 = Sub [r633; R 1005] in
  let r642 = Sub [R 225; r641] in
  let r643 = Sub [S (T T_PLUSEQ); r642] in
  let r644 = Sub [r86; r643] in
  let r645 = Sub [S (T T_LIDENT); r644] in
  let r646 = Sub [r52; R 605] in
  let r647 = Sub [r40; R 1032] in
  let r648 = Sub [R 652; r647] in
  let r649 = Sub [S (T T_SEMI); R 1023] in
  let r650 = Sub [r19; r649] in
  let r651 = Sub [S (T T_COLON); r650] in
  let r652 = Sub [R 381; R 1037] in
  let r653 = Sub [R 390; R 1030] in
  let r654 = Sub [S (N N_simple_expr_call); R 1122; R 1016] in
  let r655 = Sub [S (N N_expr); R 715] in
  let r656 = Sub [S (T T_RBRACKET); R 870] in
  let r657 = Sub [S (T T_BARRBRACKET); R 869] in
  let r658 = Sub [S (T T_GREATERRBRACE); R 875] in
  let r659 = Sub [R 642; r658] in
  let r660 = Sub [S (T T_RBRACKET); R 896] in
  let r661 = Sub [S (N N_expr); R 376] in
  let r662 = Sub [r8; R 763] in
  let r663 = Sub [S (T T_SEMI); r662] in
  let r664 = Sub [S (N N_expr); R 377] in
  let r665 = Sub [S (T T_EQUAL); r664] in
  let r666 = Sub [S (N N_expr); R 378] in
  let r667 = Sub [r8; R 760] in
  let r668 = Sub [r8; R 758] in
  let r669 = Sub [S (T T_SEMI); r668] in
  let r670 = Sub [r237; r669] in
  let r671 = Sub [R 684; r670] in
  let r672 = Sub [r8; R 757] in
  let r673 = Sub [S (T T_SEMI); r672] in
  let r674 = Sub [r8; R 759] in
  let r675 = Sub [S (T T_SEMI); r674] in
  let r676 = Sub [r237; r675] in
  let r677 = Sub [R 684; r676] in
  let r678 = Sub [S (T T_OPEN); r677] in
  let r679 = Sub [R 654; R 756] in
  let r680 = Sub [S (T T_RBRACKET); R 897] in
  let r681 = Sub [S (N N_expr); r680] in
  let r682 = Sub [S (T T_RBRACE); R 898] in
  let r683 = Sub [R 642; r682] in
  let r684 = Sub [S (T T_RBRACE); R 895] in
  let r685 = Sub [S (T T_LBRACE); r684] in
  let r686 = Sub [S (T T_RPAREN); R 912] in
  let r687 = Sub [r47; r686] in
  let r688 = Sub [S (T T_COLON); r687] in
  let r689 = Sub [S (T T_RBRACKET); R 902] in
  let r690 = Sub [S (T T_BARRBRACKET); R 901] in
  let r691 = Sub [S (T T_GREATERRBRACE); R 907] in
  let r692 = Sub [R 642; r691] in
  let r693 = Sub [S (T T_RPAREN); R 850] in
  let r694 = Sub [S (T T_RPAREN); R 556] in
  let r695 = Sub [S (T T_GREATERRBRACE); R 847] in
  let r696 = Sub [S (T T_BARRBRACKET); R 856] in
  let r697 = Sub [r40; R 582] in
  let r698 = Sub [S (T T_GREATER); R 1085] in
  let r699 = Sub [S (T T_GREATER); R 1084] in
  let r700 = Sub [S (T T_GREATER); R 1086] in
  let r701 = Sub [R 21; R 175] in
  let r702 = Sub [R 21; R 178] in
  let r703 = Sub [r633; R 1002] in
  let r704 = Sub [r633; R 1003] in
  let r705 = Sub [R 225; r704] in
  let r706 = Sub [S (T T_PLUSEQ); r705] in
  let r707 = Sub [r86; r706] in
  let r708 = Sub [S (T T_LIDENT); r707] in
  let r709 = Sub [S (T T_RPAREN); R 244] in
  let r710 = Sub [S (N N_expr); r709] in
  let r711 = Sub [S (T T_COMMA); r710] in
  let r712 = Sub [S (N N_expr); r711] in
  let r713 = Sub [S (T T_LPAREN); r712] in
  let r714 = Sub [r47; R 519] in
  let r715 = Sub [r47; R 517] in
  let r716 = Sub [r47; R 518] in
  let r717 = Sub [S (N N_expr); R 1179] in
  let r718 = Sub [S (T T_RBRACE); R 60] in
  let r719 = Sub [R 642; r718] in
  let r720 = Sub [S (T T_DOT); r327] in
  let r721 = Sub [R 218; R 1049] in
  let r722 = Sub [S (T T_EOF); R 207; R 1171] in
  let r723 = Sub [S (T T_COLONEQUAL); r525] in
  let r724 = Sub [S (T T_EQUAL); r619] in
  let r725 = Sub [S (T T_RBRACKET); r724] in
  let r726 = Sub [S (T T_EQUAL); r620] in
  let r727 = Sub [S (T T_RBRACKET); r726] in
  let r728 = Sub [S (N N_expr); r727] in
  let r729 = Sub [S (T T_EQUAL); r621] in
  let r730 = Sub [S (T T_RBRACE); r729] in
  let r731 = Sub [R 642; r730] in
  function
  | 0 | 2462 | 2466 | 2470 | 2474 | 2478 | 2495 -> Nothing
  | 1 -> One [R 682; r4]
  | 2 -> One [r5; R 321]
  | 3 -> One [R 999]
  | 4 -> One [R 998]
  | 5 -> One [R 997]
  | 6 -> One [R 996]
  | 7 -> One [R 995]
  | 8 -> One [R 951]
  | 9 -> One [R 994]
  | 10 -> One [R 993]
  | 11 -> One [R 992]
  | 12 -> One [R 991]
  | 13 -> One [R 990]
  | 14 -> One [R 977]
  | 15 -> One [R 989]
  | 16 -> One [R 988]
  | 17 -> One [R 987]
  | 18 -> One [R 986]
  | 19 -> One [R 985]
  | 20 -> One [R 984]
  | 21 -> One [R 983]
  | 22 -> One [R 982]
  | 23 -> One [R 981]
  | 24 -> One [R 980]
  | 25 -> One [R 979]
  | 26 -> One [R 978]
  | 27 -> One [R 950]
  | 28 -> One [R 976]
  | 29 -> One [R 975]
  | 30 -> One [R 974]
  | 31 -> One [R 973]
  | 32 -> One [R 972]
  | 33 -> One [R 971]
  | 34 -> One [R 970]
  | 35 -> One [R 969]
  | 36 -> One [R 968]
  | 37 -> One [R 967]
  | 38 -> One [R 966]
  | 39 -> One [R 965]
  | 40 -> One [R 964]
  | 41 -> One [R 963]
  | 42 -> One [R 962]
  | 43 -> One [R 961]
  | 44 -> One [R 960]
  | 45 -> One [R 959]
  | 46 -> One [R 958]
  | 47 -> One [R 957]
  | 48 -> One [R 956]
  | 49 -> One [R 955]
  | 50 -> One [R 954]
  | 51 -> One [R 953]
  | 52 -> One [R 952]
  | 53 -> One [R 34]
  | 54 -> One [r5; R 35]
  | 55 -> One [R 35]
  | 56 -> One [R 321]
  | 57 -> One [r4]
  | 58 -> One [r1]
  | 59 -> One [R 682; r7]
  | 60 -> One [r7]
  | 61 -> One [r8; r9]
  | 62 -> One [r14; R 96]
  | 63 -> One [R 546; r22]
  | 64 -> One [R 547]
  | 65 -> One [r22]
  | 66 -> One [r21]
  | 67 -> One [r19; R 1052]
  | 68 -> One [R 50]
  | 69 -> One [R 501]
  | 70 -> One [r26]
  | 71 -> One [R 448]
  | 72 -> One [r27]
  | 73 -> One [R 502]
  | 74 -> One [r24; r28]
  | 75 -> One [R 503]
  | 76 -> One [r24; r29]
  | 77 -> One [r29]
  | 78 -> One [R 494]
  | 79 -> One [r23; R 449]
  | 80 -> One [R 449]
  | 81 -> One [r28]
  | 82 -> One [R 493]
  | 83 -> One [r25]
  | 84 -> One [R 492]
  | 85 -> One [S (T T_LIDENT); r34]
  | 86 -> One [r34]
  | 87 -> One [r33]
  | 88 -> One [r35; R 49]
  | 89 -> One [R 506]
  | 90 -> One [R 111]
  | 91 -> One [S (T T_DOT); r36]
  | 92 -> One [r36]
  | 93 -> One [R 507]
  | 94 -> One [R 112]
  | 95 -> One [R 49]
  | 96 -> One [r37; r39]
  | 97 -> One [r41]
  | 98 -> One [R 316]
  | 99 -> One [R 317]
  | 100 -> One [R 48]
  | 101 -> One [r47; R 719]
  | 102 -> One [R 501]
  | 103 -> One [r50]
  | 104 -> One [R 505]
  | 105 -> One [R 504]
  | 106 -> One [R 309]
  | 107 -> One [S (T T_TYPE); r55]
  | 108 -> One [r55]
  | 109 -> One [r54]
  | 110 -> One [r51]
  | 111 -> One [S (N N_expr); R 516]
  | 112 -> One [R 682; r68]
  | 113 -> One [r68]
  | 114 -> One [R 155]
  | 115 -> One [R 150]
  | 116 -> One [S (N N_simple_expr_no_constructor); R 905]
  | 117 -> One [r35; R 906]
  | 118 -> One [R 906]
  | 119 -> One [r70]
  | 120 -> One [R 682; r75]
  | 121 -> One [r75]
  | 122 -> One [R 1172]
  | 123 -> One [R 498]
  | 124 -> One [r24; r76]
  | 125 -> One [r76]
  | 126 -> One [R 495]
  | 127 -> One [R 326; R 332]
  | 128 -> One [S (T T_LIDENT); r77]
  | 129 -> One [r77]
  | 130 -> One [R 326; R 330]
  | 131 -> One [R 331]
  | 132 -> One [S (N N_simple_expr_call); r78]
  | 133 -> One [S (N N_simple_expr_call); r79]
  | 134 -> One [S (N N_simple_expr_call); R 831]
  | 135 -> One [r35; R 832]
  | 136 -> One [R 832]
  | 137 -> One [r70]
  | 138 -> One [R 622]
  | 139 -> One [R 616]
  | 140 -> One [R 153]
  | 141 -> One [R 608]
  | 142 -> One [R 406; r80]
  | 143 -> One [S (N N_simple_expr_no_call); R 873]
  | 144 -> One [r35; R 874]
  | 145 -> One [R 874]
  | 146 -> One [r70]
  | 147 -> One [R 609]
  | 148 -> One [R 629]
  | 149 -> One [R 619]
  | 150 -> One [S (N N_expr); R 271]
  | 151 -> One [S (N N_expr); R 270]
  | 152 -> One [S (N N_expr); R 269]
  | 153 -> One [S (N N_expr); R 268]
  | 155 -> One [R 618]
  | 157 -> One [r81]
  | 158 -> One [S (T T_LIDENT); r82]
  | 159 -> One [r82]
  | 160 -> One [R 333]
  | 161 -> One [R 326; R 334]
  | 162 -> One [R 334]
  | 163 -> One [r5; r85]
  | 164 -> One [r85]
  | 165 -> One [r93]
  | 166 -> One [R 587]
  | 167 -> One [r92]
  | 168 -> One [r95]
  | 169 -> One [r99]
  | 170 -> One [R 213]
  | 171 -> One [r40; R 212]
  | 172 -> One [R 212]
  | 173 -> One [S (T T_UNDERSCORE); R 215]
  | 174 -> One [R 215]
  | 175 -> One [r40; R 214]
  | 176 -> One [R 214]
  | 177 -> One [S (T T_UNDERSCORE); R 217]
  | 178 -> One [R 217]
  | 179 -> One [r40; R 216]
  | 180 -> One [R 216]
  | 181 -> One [r98]
  | 182 -> One [R 427]
  | 183 -> One [R 476]
  | 184 -> One [r96]
  | 185 -> One [R 643]
  | 186 -> One [R 477]
  | 187 -> One [R 1113]
  | 188 -> One [R 1116]
  | 189 -> One [r97; r100]
  | 190 -> One [r100]
  | 191 -> One [R 1115]
  | 192 -> One [r94]
  | 193 -> One [S (T T_DOTDOT); R 1073]
  | 194 -> One [r103]
  | 196 -> One [R 1064]
  | 197 -> One [r105]
  | 198 -> One [r37; r107]
  | 199 -> One [r111; r113]
  | 200 -> One [R 430; r114]
  | 201 -> One [r5; r116]
  | 202 -> One [r116]
  | 203 -> One [R 682; r121]
  | 204 -> One [r121]
  | 205 -> One [r124; r125]
  | 206 -> One [R 326; R 337]
  | 207 -> One [R 337]
  | 208 -> One [r123]
  | 209 -> One [R 642; r126]
  | 210 -> One [R 647]
  | 211 -> One [R 643]
  | 212 -> One [r128]
  | 213 -> One [R 642; r129]
  | 214 -> One [r129]
  | 215 -> One [R 813]
  | 216 -> One [R 642; r130]
  | 217 -> One [R 643]
  | 218 -> One [r127; R 457]
  | 220 -> One [R 152]
  | 221 -> One [r131]
  | 222 -> One [R 282]
  | 223 -> One [r132]
  | 224 -> One [R 841]
  | 225 -> One [S (T T_GREATERRBRACE); R 848]
  | 226 -> One [R 300]
  | 227 -> One [S (N N_expr); R 299]
  | 228 -> One [S (N N_simple_expr_call); R 279]
  | 229 -> One [R 147]
  | 230 -> One [R 149]
  | 231 -> One [R 154]
  | 232 -> One [R 148]
  | 233 -> One [r40; R 816]
  | 234 -> One [R 816]
  | 235 -> One [S (T T_RPAREN); R 557]
  | 236 -> One [R 557]
  | 237 -> One [r52; r133]
  | 238 -> One [R 1013; r134]
  | 239 -> One [R 682; r139]
  | 240 -> One [r139]
  | 241 -> One [R 642; r140]
  | 242 -> One [r140]
  | 243 -> One [R 887]
  | 244 -> One [R 642; r141]
  | 245 -> One [r141]
  | 246 -> One [R 888]
  | 247 -> One [r142]
  | 248 -> One [r40; R 890]
  | 249 -> One [R 890]
  | 250 -> One [R 883]
  | 251 -> One [R 1174]
  | 252 -> One [r138]
  | 253 -> One [S (N N_simple_expr_no_call); R 909]
  | 254 -> One [r40; R 858]
  | 255 -> One [R 858]
  | 256 -> One [R 917]
  | 257 -> One [R 916]
  | 258 -> One [R 843]
  | 259 -> One [R 851]
  | 260 -> One [R 882]
  | 261 -> One [R 909]
  | 262 -> One [R 854]
  | 263 -> One [S (T T_DOT); r144]
  | 264 -> One [r144]
  | 265 -> One [r70]
  | 266 -> One [R 630]
  | 267 -> One [R 624]
  | 268 -> One [r52; r147]
  | 269 -> One [R 187]
  | 270 -> One [R 186]
  | 271 -> One [R 37]
  | 272 -> One [R 522]
  | 273 -> One [r147]
  | 274 -> One [R 642; R 510; r148]
  | 275 -> One [R 510]
  | 276 -> One [R 514]
  | 277 -> One [r46; R 515]
  | 278 -> One [r43]
  | 279 -> One [r93]
  | 280 -> One [r92]
  | 281 -> One [r90]
  | 282 -> One [r99]
  | 283 -> One [r89]
  | 284 -> One [R 225; r153]
  | 285 -> One [R 226]
  | 286 -> One [r153]
  | 287 -> One [r154]
  | 288 -> One [r158]
  | 289 -> One [r111; r159]
  | 290 -> One [r160]
  | 291 -> One [R 599]
  | 292 -> One [R 422; r161]
  | 293 -> One [S (T T_COLON); r163]
  | 294 -> One [r163]
  | 297 -> One [r164]
  | 298 -> One [R 564]
  | 299 -> One [R 565]
  | 300 -> One [S (T T_LPAREN); r169; r171]
  | 301 -> One [r169]
  | 302 -> One [R 645]
  | 303 -> One [r166]
  | 304 -> One [S (T T_LIDENT); r173]
  | 305 -> One [r173]
  | 306 -> One [r172]
  | 307 -> One [R 182]
  | 308 -> One [R 555]
  | 309 -> One [R 51]
  | 310 -> One [R 46]
  | 311 -> One [R 28]
  | 312 -> One [r31]
  | 313 -> One [R 681]
  | 314 -> One [R 363]
  | 315 -> One [R 52]
  | 316 -> One [r174]
  | 317 -> One [R 183]
  | 318 -> One [R 553]
  | 319 -> One [R 1120]
  | 320 -> One [S (T T_DOT); r175]
  | 322 -> One [R 1065]
  | 323 -> One [S (T T_EQUALGREATER); r176]
  | 324 -> One [r176]
  | 325 -> One [R 56]
  | 326 -> One [R 32]
  | 327 -> One [R 554]
  | 328 -> One [r18; R 33]
  | 329 -> One [R 33]
  | 330 -> One [R 562]
  | 331 -> One [R 563]
  | 332 -> One [R 1121]
  | 333 -> One [R 180]
  | 334 -> One [S (T T_QUOTE); r177]
  | 335 -> One [r177]
  | 336 -> One [R 181]
  | 337 -> One [R 720]
  | 338 -> One [R 27]
  | 339 -> One [R 29]
  | 340 -> One [R 478]
  | 341 -> One [r168]
  | 342 -> One [R 643]
  | 343 -> One [r165; R 479]
  | 344 -> One [R 479]
  | 345 -> One [r167]
  | 346 -> One [R 30]
  | 347 -> One [r171]
  | 348 -> One [r170]
  | 349 -> One [R 31]
  | 350 -> One [R 1010]
  | 351 -> One [S (T T_DOT); r178]
  | 352 -> One [r178]
  | 353 -> One [R 717]
  | 354 -> One [R 716]
  | 355 -> One [R 593]
  | 356 -> One [r162; R 595]
  | 357 -> One [R 595]
  | 358 -> One [r15; R 597]
  | 359 -> One [R 597]
  | 360 -> One [S (T T_RBRACE); R 601]
  | 361 -> One [R 601]
  | 362 -> One [R 472]
  | 363 -> One [R 423]
  | 364 -> One [R 454]
  | 365 -> One [r179]
  | 366 -> One [r181]
  | 367 -> One [r180]
  | 368 -> One [R 1011]
  | 369 -> One [R 594]
  | 370 -> One [r162; R 596]
  | 371 -> One [R 596]
  | 372 -> One [R 642; R 1012]
  | 373 -> One [R 643]
  | 374 -> One [R 473]
  | 375 -> One [S (T T_STRING); r181]
  | 376 -> One [R 1012]
  | 377 -> One [R 642; R 598]
  | 378 -> One [R 643]
  | 379 -> One [R 455]
  | 380 -> One [r179]
  | 381 -> One [R 598]
  | 382 -> One [r161]
  | 383 -> One [R 603]
  | 384 -> One [R 422; r182]
  | 385 -> One [S (T T_RBRACE); R 600]
  | 386 -> One [R 600]
  | 387 -> One [r182]
  | 388 -> One [R 602]
  | 389 -> One [r109; R 44]
  | 390 -> One [r40; R 1047]
  | 391 -> One [R 1047]
  | 392 -> One [R 58]
  | 393 -> One [r183; R 1045]
  | 394 -> One [R 1045]
  | 395 -> One [R 750]
  | 396 -> One [r183; R 751]
  | 397 -> One [R 751]
  | 398 -> One [R 746]
  | 399 -> One [R 44]
  | 400 -> One [r185]
  | 401 -> One [r184]
  | 402 -> One [R 1048]
  | 403 -> One [r183; R 1046]
  | 404 -> One [R 1046]
  | 405 -> One [R 551]
  | 406 -> One [R 747]
  | 407 -> One [R 554]
  | 408 -> One [R 562]
  | 409 -> One [R 552]
  | 410 -> One [r159]
  | 411 -> One [R 53]
  | 412 -> One [r110]
  | 413 -> One [S (T T_BAR); r186]
  | 414 -> One [r186]
  | 415 -> One [R 45]
  | 416 -> One [R 748]
  | 417 -> One [R 404; R 405]
  | 418 -> One [R 405]
  | 419 -> One [r185]
  | 420 -> One [R 404; R 749]
  | 421 -> One [R 749]
  | 423 -> One [R 468]
  | 424 -> One [R 546; r187]
  | 425 -> One [r187]
  | 426 -> One [R 743]
  | 427 -> One [r162; R 745]
  | 428 -> One [R 745]
  | 429 -> One [r188]
  | 430 -> One [R 742]
  | 431 -> One [r162; R 744]
  | 432 -> One [R 744]
  | 433 -> One [r190]
  | 434 -> One [R 643]
  | 435 -> One [R 469]
  | 436 -> One [r189]
  | 437 -> One [R 723]
  | 438 -> One [S (T T_RPAREN); R 160]
  | 439 -> One [R 160]
  | 440 -> One [r156]
  | 441 -> One [R 643]
  | 442 -> One [R 439]
  | 443 -> One [R 162]
  | 444 -> One [R 438]
  | 445 -> One [r157]
  | 446 -> One [R 161]
  | 447 -> One [R 159]
  | 448 -> One [r101]
  | 449 -> One [r19; R 665]
  | 450 -> One [R 665]
  | 451 -> One [R 313]
  | 452 -> One [R 158]
  | 453 -> One [R 287]
  | 454 -> One [R 659]
  | 455 -> One [r149]
  | 456 -> One [R 292]
  | 457 -> One [r192]
  | 458 -> One [r191]
  | 459 -> One [R 289]
  | 460 -> One [r194]
  | 461 -> One [r193]
  | 462 -> One [R 288]
  | 463 -> One [r195]
  | 464 -> One [R 291]
  | 465 -> One [r196]
  | 466 -> One [R 290]
  | 467 -> One [r150; R 574]
  | 468 -> One [r150; R 575]
  | 469 -> One [R 575]
  | 470 -> One [R 579]
  | 471 -> One [S (T T_BAR); r197]
  | 472 -> One [r197]
  | 473 -> One [r150; R 577]
  | 474 -> One [R 577]
  | 475 -> One [R 581]
  | 476 -> One [R 576]
  | 477 -> One [R 580]
  | 478 -> One [R 574]
  | 479 -> One [R 578]
  | 480 -> One [R 41]
  | 481 -> One [r151]
  | 482 -> One [r150; r198]
  | 483 -> One [r150; r199]
  | 484 -> One [r199]
  | 485 -> One [S (T T_BAR); r201]
  | 486 -> One [r201]
  | 487 -> One [r150; r202]
  | 488 -> One [r202]
  | 489 -> One [R 403]
  | 490 -> One [r200]
  | 491 -> One [R 402]
  | 492 -> One [R 401]
  | 493 -> One [r198]
  | 494 -> One [R 400]
  | 495 -> One [R 40]
  | 496 -> One [R 766]
  | 497 -> One [r203]
  | 498 -> One [r204]
  | 499 -> One [R 168]
  | 500 -> One [S (T T_DOTDOT); R 1106]
  | 501 -> One [r206]
  | 502 -> One [r205]
  | 503 -> One [R 165]
  | 504 -> One [R 466]
  | 505 -> One [r39]
  | 506 -> One [R 643]
  | 507 -> One [R 467]
  | 508 -> One [r38]
  | 509 -> One [R 1081]
  | 510 -> One [r208]
  | 511 -> One [r207]
  | 512 -> One [R 164]
  | 513 -> One [r102; R 167]
  | 514 -> One [R 167]
  | 515 -> One [R 1106]
  | 516 -> One [r102; R 166]
  | 517 -> One [R 166]
  | 518 -> One [r209; R 42]
  | 519 -> One [r103]
  | 520 -> One [R 163]
  | 521 -> One [r206]
  | 522 -> One [r208]
  | 523 -> One [r211]
  | 524 -> One [r212]
  | 525 -> One [R 169]
  | 526 -> One [r102; R 174]
  | 527 -> One [R 174]
  | 528 -> One [r214]
  | 529 -> One [r213]
  | 530 -> One [R 171]
  | 531 -> One [r216]
  | 532 -> One [r215]
  | 533 -> One [R 170]
  | 534 -> One [r102; R 173]
  | 535 -> One [R 173]
  | 536 -> One [r210]
  | 537 -> One [R 172]
  | 538 -> One [R 42]
  | 539 -> One [R 1094]
  | 540 -> One [R 1103]
  | 541 -> One [r174]
  | 542 -> One [r212]
  | 543 -> One [r214]
  | 544 -> One [r216]
  | 545 -> One [r217]
  | 546 -> One [R 43]
  | 547 -> One [R 1104]
  | 548 -> One [r219]
  | 549 -> One [r19; r221; R 584]
  | 550 -> One [r221]
  | 551 -> One [r220]
  | 552 -> One [R 156]
  | 553 -> One [R 584]
  | 554 -> One [R 585]
  | 555 -> One [S (T T_LIDENT); r225]
  | 556 -> One [r225]
  | 557 -> One [r224]
  | 558 -> One [r222]
  | 559 -> One [R 24; R 1098]
  | 560 -> One [S (T T_AND); r228]
  | 561 -> One [r228]
  | 562 -> One [r227]
  | 563 -> One [r226]
  | 564 -> One [R 26]
  | 565 -> One [R 1114]
  | 566 -> One [R 1098]
  | 567 -> One [R 1097]
  | 568 -> One [R 25]
  | 569 -> One [R 1087]
  | 570 -> One [R 24; R 1090]
  | 571 -> One [R 1090]
  | 572 -> One [r229]
  | 573 -> One [r218; R 1088]
  | 574 -> One [R 1088]
  | 575 -> One [R 1089]
  | 576 -> One [R 1100]
  | 577 -> One [R 190]
  | 578 -> One [R 191]
  | 579 -> One [R 1105]
  | 580 -> One [R 1093]
  | 581 -> One [R 1101]
  | 582 -> One [r174]
  | 583 -> One [R 1102]
  | 584 -> One [R 1099]
  | 585 -> One [S (T T_DOTDOT); R 1107]
  | 586 -> One [r209; R 190; r219; R 1096]
  | 587 -> One [r230]
  | 588 -> One [R 1096]
  | 589 -> One [R 1110]
  | 590 -> One [r211]
  | 591 -> One [R 1111]
  | 592 -> One [R 1107]
  | 593 -> One [R 1095]
  | 594 -> One [R 1108]
  | 595 -> One [r211]
  | 596 -> One [R 1109]
  | 597 -> One [R 1091]
  | 598 -> One [r87]
  | 599 -> One [r91; R 22]
  | 600 -> One [r95]
  | 601 -> One [r90]
  | 602 -> One [r89]
  | 603 -> One [R 1055]
  | 604 -> One [R 22]
  | 605 -> One [R 21; R 1061]
  | 606 -> One [S (T T_AND); r231]
  | 607 -> One [r231]
  | 608 -> One [R 23]
  | 609 -> One [R 1061]
  | 610 -> One [R 1060]
  | 611 -> One [R 1062]
  | 612 -> One [S (T T_DOT); r236]
  | 613 -> One [r236]
  | 614 -> One [r235]
  | 615 -> One [r234]
  | 616 -> One [r233]
  | 617 -> One [r232]
  | 618 -> One [R 767]
  | 619 -> One [R 684; r238]
  | 620 -> One [R 685]
  | 621 -> One [r238]
  | 622 -> One [R 606]
  | 623 -> One [r239]
  | 625 -> One [r240]
  | 626 -> One [R 791]
  | 627 -> One [r46; R 541]
  | 628 -> One [R 536]
  | 629 -> One [R 920]
  | 630 -> One [R 919]
  | 631 -> One [R 541]
  | 632 -> One [r244; R 436; R 535]
  | 633 -> One [r245; r248]
  | 634 -> One [R 342]
  | 635 -> One [S (T T_DOT); r249]
  | 636 -> One [r249]
  | 637 -> One [R 343]
  | 638 -> One [r248]
  | 639 -> One [r247]
  | 640 -> One [R 225; r250]
  | 641 -> One [r250]
  | 642 -> One [R 1185]
  | 643 -> One [R 1186]
  | 644 -> One [r246]
  | 645 -> One [R 1187]
  | 646 -> One [r243]
  | 647 -> One [r242]
  | 648 -> One [r241]
  | 649 -> One [R 1189]
  | 650 -> One [S (T T_EQUAL); r251]
  | 651 -> One [r251]
  | 652 -> One [R 1188]
  | 653 -> One [R 436]
  | 654 -> One [R 535]
  | 655 -> One [r244; R 437]
  | 656 -> One [R 437]
  | 657 -> One [S (T T_DOT); r252]
  | 658 -> One [r252]
  | 659 -> One [R 316]
  | 660 -> One [R 545]
  | 661 -> One [R 544]
  | 662 -> One [S (T T_EQUALGREATER); r253]
  | 663 -> One [r253]
  | 664 -> One [R 538]
  | 665 -> One [R 921]
  | 666 -> One [r46; R 537]
  | 667 -> One [R 537]
  | 668 -> One [R 542]
  | 669 -> One [R 793]
  | 671 -> One [R 637]
  | 672 -> One [r70]
  | 673 -> One [R 608]
  | 674 -> One [R 619]
  | 675 -> One [R 618]
  | 676 -> One [R 621]
  | 677 -> One [R 620]
  | 678 -> One [R 634]
  | 679 -> One [R 632]
  | 680 -> One [R 623]
  | 681 -> One [R 617]
  | 682 -> One [R 615]
  | 683 -> One [R 614]
  | 684 -> One [R 613]
  | 685 -> One [R 612]
  | 686 -> One [R 631]
  | 687 -> One [R 611]
  | 688 -> One [R 633]
  | 689 -> One [R 628]
  | 690 -> One [R 625]
  | 691 -> One [R 610]
  | 692 -> One [R 635]
  | 693 -> One [R 626]
  | 694 -> One [R 627]
  | 695 -> One [r69]
  | 696 -> One [R 1173]
  | 697 -> One [r255]
  | 698 -> One [r254]
  | 699 -> One [R 773]
  | 700 -> One [r5; r257]
  | 701 -> One [r257]
  | 702 -> One [r58; R 713]
  | 703 -> One [R 930]
  | 704 -> One [S (T T_LIDENT); R 1064; R 936]
  | 705 -> One [R 936]
  | 706 -> One [S (T T_INT); R 807]
  | 707 -> One [R 807]
  | 708 -> One [R 808]
  | 709 -> One [S (T T_INT); R 805]
  | 710 -> One [R 805]
  | 711 -> One [R 806]
  | 713 -> One [R 618]
  | 714 -> One [r258; r259]
  | 715 -> One [R 504]
  | 716 -> One [r259]
  | 717 -> One [R 938]
  | 718 -> One [r261]
  | 719 -> One [R 651]
  | 720 -> One [r260]
  | 721 -> One [R 700]
  | 722 -> One [R 686]
  | 723 -> One [R 620]
  | 724 -> One [R 432; r262]
  | 725 -> One [r263]
  | 727 -> One [r264]
  | 728 -> One [R 942]
  | 729 -> One [r265]
  | 730 -> One [R 643]
  | 731 -> One [r58; R 463]
  | 732 -> One [r267; r268]
  | 733 -> One [r266]
  | 734 -> One [R 7]
  | 735 -> One [R 8]
  | 736 -> One [R 642; R 9]
  | 737 -> One [R 9]
  | 738 -> One [R 10]
  | 739 -> One [R 365]
  | 740 -> One [r58; R 364]
  | 741 -> One [r56; R 708]
  | 742 -> One [r70]
  | 743 -> One [r57; R 707]
  | 744 -> One [r269]
  | 745 -> One [R 935]
  | 746 -> One [r269]
  | 747 -> One [R 935]
  | 748 -> One [R 929]
  | 749 -> One [R 939]
  | 750 -> One [R 924]
  | 751 -> One [R 923]
  | 752 -> One [R 704]
  | 753 -> One [R 931]
  | 754 -> One [r270; R 932]
  | 755 -> One [R 932]
  | 756 -> One [R 804]
  | 757 -> One [r270; R 933]
  | 758 -> One [R 933]
  | 760 -> One [r272]
  | 761 -> One [S (T T_RPAREN); R 949]
  | 762 -> One [R 949]
  | 763 -> One [R 701]
  | 764 -> One [R 693]
  | 765 -> One [r57; R 705]
  | 766 -> One [R 705]
  | 767 -> One [R 940]
  | 768 -> One [R 934]
  | 769 -> One [r273; R 464; r275]
  | 770 -> One [r258; r276]
  | 771 -> One [r276]
  | 772 -> One [R 464]
  | 773 -> One [R 698]
  | 774 -> One [r19; R 699]
  | 775 -> One [R 699]
  | 776 -> One [r58; R 694]
  | 777 -> One [R 694]
  | 778 -> One [r57; R 709]
  | 779 -> One [R 709]
  | 780 -> One [r275]
  | 781 -> One [R 643]
  | 782 -> One [R 465]
  | 783 -> One [r274]
  | 784 -> One [R 697]
  | 785 -> One [R 432; r277]
  | 786 -> One [R 642; R 433]
  | 787 -> One [R 433]
  | 788 -> One [r277]
  | 789 -> One [R 928]
  | 790 -> One [r278; r279]
  | 791 -> One [r279]
  | 792 -> One [R 927]
  | 793 -> One [r267; r280]
  | 794 -> One [r280]
  | 795 -> One [R 926]
  | 796 -> One [R 696]
  | 797 -> One [R 703]
  | 798 -> One [R 151]
  | 799 -> One [R 925]
  | 800 -> One [r281; R 702]
  | 801 -> One [R 702]
  | 802 -> One [S (T T_RPAREN); R 947]
  | 803 -> One [R 947]
  | 804 -> One [R 432; r282]
  | 805 -> One [r282]
  | 806 -> One [R 946]
  | 807 -> One [r271]
  | 808 -> One [R 948]
  | 809 -> One [S (T T_RBRACKET); R 945]
  | 810 -> One [R 945]
  | 811 -> One [r267; r283]
  | 812 -> One [r283]
  | 813 -> One [R 944]
  | 814 -> One [R 934]
  | 815 -> One [R 707]
  | 816 -> One [R 642; r284]
  | 817 -> One [r284]
  | 818 -> One [R 937]
  | 819 -> One [R 708]
  | 820 -> One [R 364]
  | 821 -> One [r281; R 366]
  | 822 -> One [R 366]
  | 823 -> One [r268]
  | 824 -> One [R 941]
  | 825 -> One [R 463]
  | 826 -> One [R 695]
  | 827 -> One [R 462]
  | 828 -> One [r262]
  | 829 -> One [R 943]
  | 830 -> One [S (T T_RPAREN); r289]
  | 831 -> One [r289]
  | 832 -> One [r288]
  | 833 -> One [r287]
  | 834 -> One [r286]
  | 835 -> One [r285]
  | 836 -> One [R 706]
  | 837 -> One [R 713]
  | 838 -> One [S (N N_expr); R 714]
  | 839 -> One [R 682; r291]
  | 840 -> One [r291]
  | 841 -> One [r290]
  | 842 -> One [R 809]
  | 843 -> One [R 842]
  | 844 -> One [R 812]
  | 845 -> One [R 240]
  | 846 -> One [S (N N_simple_expr_no_call); R 835]
  | 847 -> One [R 835]
  | 848 -> One [R 326; R 335]
  | 849 -> One [S (T T_UIDENT); R 499]
  | 850 -> One [R 499]
  | 851 -> One [r24; r292]
  | 852 -> One [r292]
  | 853 -> One [R 496]
  | 854 -> One [R 335]
  | 855 -> One [R 500]
  | 856 -> One [r24; r293]
  | 857 -> One [r293]
  | 858 -> One [R 497]
  | 859 -> One [S (T T_SLASHGREATER); R 323]
  | 860 -> One [R 323]
  | 861 -> One [R 314]
  | 862 -> One [R 406; r294]
  | 863 -> One [R 315]
  | 864 -> One [R 406; R 407]
  | 865 -> One [S (N N_simple_expr_no_call); R 877]
  | 866 -> One [R 877]
  | 867 -> One [R 853]
  | 868 -> One [R 881]
  | 869 -> One [R 857]
  | 870 -> One [R 915]
  | 871 -> One [R 914]
  | 872 -> One [R 852]
  | 873 -> One [S (N N_simple_expr_call); R 878]
  | 874 -> One [R 878]
  | 875 -> One [R 818]
  | 876 -> One [S (N N_simple_expr_no_call); R 837]
  | 877 -> One [R 837]
  | 878 -> One [R 642; r295]
  | 879 -> One [S (T T_RPAREN); R 347]
  | 880 -> One [R 347]
  | 881 -> One [r296; R 480]
  | 882 -> One [R 353]
  | 883 -> One [r281; R 1174; r297]
  | 884 -> One [r70]
  | 885 -> One [R 678; R 415]
  | 886 -> One [r299]
  | 887 -> One [r47; R 1053]
  | 888 -> One [R 1053]
  | 889 -> One [r298]
  | 890 -> One [r19; R 675]
  | 891 -> One [R 675]
  | 892 -> One [R 1051]
  | 893 -> One [R 679]
  | 894 -> One [R 415]
  | 895 -> One [S (T T_DOT); r300]
  | 897 -> One [R 1175]
  | 898 -> One [S (T T_RPAREN); R 194]
  | 899 -> One [R 194]
  | 900 -> One [R 1172]
  | 901 -> One [R 680; r301]
  | 902 -> One [r301]
  | 903 -> One [R 352]
  | 904 -> One [R 682; r308]
  | 905 -> One [r308]
  | 906 -> One [r306]
  | 907 -> One [S (T T_LIDENT); R 360]
  | 908 -> One [R 360]
  | 909 -> One [S (T T_LIDENT); r309]
  | 910 -> One [r309]
  | 911 -> One [r273; R 361]
  | 912 -> One [R 361]
  | 913 -> One [R 362]
  | 914 -> One [R 356]
  | 915 -> One [S (N N_expr); R 357]
  | 916 -> One [R 358]
  | 917 -> One [R 682; r318]
  | 918 -> One [r318]
  | 919 -> One [r317]
  | 920 -> One [r316]
  | 921 -> One [r315]
  | 922 -> One [r319; r321]
  | 923 -> One [R 231]
  | 924 -> One [S (T T_RPAREN); R 227]
  | 925 -> One [R 227]
  | 926 -> One [S (T T_RPAREN); R 229]
  | 927 -> One [R 229]
  | 928 -> One [R 359]
  | 929 -> One [R 642; r322]
  | 930 -> One [R 643]
  | 931 -> One [R 447]
  | 932 -> One [r322]
  | 933 -> One [R 230]
  | 934 -> One [R 446]
  | 935 -> One [R 642; r323]
  | 936 -> One [r323]
  | 937 -> One [R 228]
  | 938 -> One [R 232]
  | 939 -> One [r321]
  | 940 -> One [r320]
  | 941 -> One [S (N N_expr); R 272]
  | 942 -> One [S (N N_simple_expr_call); R 278]
  | 943 -> One [R 278]
  | 944 -> One [S (N N_simple_expr_call); R 836]
  | 945 -> One [R 836]
  | 946 -> One [r325]
  | 947 -> One [R 233]
  | 948 -> One [S (T T_LIDENT); R 834]
  | 949 -> One [R 834]
  | 950 -> One [r325]
  | 952 -> One [r327]
  | 953 -> One [r70]
  | 954 -> One [r52; r330]
  | 955 -> One [r330]
  | 956 -> One [r329]
  | 957 -> One [r328]
  | 958 -> One [R 838]
  | 959 -> One [R 508]
  | 960 -> One [R 527]
  | 961 -> One [R 521]
  | 962 -> One [R 525]
  | 963 -> One [S (T T_LPAREN); r331; r334]
  | 964 -> One [r331]
  | 965 -> One [r48]
  | 966 -> One [R 532]
  | 967 -> One [R 534]
  | 968 -> One [r49]
  | 969 -> One [R 918]
  | 970 -> One [S (T T_RPAREN); R 311]
  | 971 -> One [R 311]
  | 972 -> One [R 452]
  | 973 -> One [S (T T_COLON); r335]
  | 974 -> One [r335]
  | 975 -> One [R 533]
  | 976 -> One [R 642; r336]
  | 977 -> One [R 643]
  | 978 -> One [R 453]
  | 979 -> One [r336]
  | 980 -> One [R 312]
  | 981 -> One [S (T T_RPAREN); R 310]
  | 982 -> One [R 310]
  | 983 -> One [r334]
  | 984 -> One [r45; R 673]
  | 985 -> One [r50]
  | 986 -> One [r49]
  | 987 -> One [R 918]
  | 988 -> One [R 673]
  | 989 -> One [r333]
  | 990 -> One [r332]
  | 991 -> One [R 526]
  | 992 -> One [r52; R 528]
  | 993 -> One [R 528]
  | 994 -> One [R 621]
  | 995 -> One [R 811]
  | 996 -> One [R 839]
  | 997 -> One [R 269]
  | 998 -> One [R 815]
  | 999 -> One [R 810]
  | 1000 -> One [r337]
  | 1001 -> One [R 281]
  | 1002 -> One [R 620]
  | 1003 -> One [R 268]
  | 1004 -> One [R 623]
  | 1005 -> One [R 610]
  | 1006 -> One [R 272]
  | 1007 -> One [r338]
  | 1008 -> One [R 643]
  | 1009 -> One [R 443]
  | 1010 -> One [R 284]
  | 1011 -> One [S (N N_expr); R 256]
  | 1012 -> One [R 256]
  | 1013 -> One [S (N N_expr); R 251]
  | 1014 -> One [R 251]
  | 1015 -> One [S (N N_expr); R 250]
  | 1016 -> One [R 250]
  | 1017 -> One [S (N N_expr); r340]
  | 1018 -> One [r340]
  | 1019 -> One [S (N N_expr); R 263]
  | 1020 -> One [R 263]
  | 1021 -> One [S (N N_expr); R 264]
  | 1022 -> One [R 264]
  | 1023 -> One [S (N N_expr); R 249]
  | 1024 -> One [R 249]
  | 1025 -> One [S (N N_expr); R 253]
  | 1026 -> One [R 253]
  | 1027 -> One [S (N N_expr); R 252]
  | 1028 -> One [R 252]
  | 1029 -> One [S (N N_expr); R 258]
  | 1030 -> One [R 258]
  | 1031 -> One [S (N N_expr); R 255]
  | 1032 -> One [R 255]
  | 1033 -> One [S (N N_expr); R 254]
  | 1034 -> One [R 254]
  | 1035 -> One [S (N N_expr); R 266]
  | 1036 -> One [R 266]
  | 1037 -> One [S (N N_expr); R 248]
  | 1038 -> One [R 248]
  | 1039 -> One [S (N N_expr); R 247]
  | 1040 -> One [R 247]
  | 1041 -> One [S (N N_expr); R 257]
  | 1042 -> One [R 257]
  | 1043 -> One [S (N N_expr); R 246]
  | 1044 -> One [R 246]
  | 1045 -> One [S (N N_expr); R 265]
  | 1046 -> One [R 265]
  | 1047 -> One [S (N N_expr); R 245]
  | 1048 -> One [S (N N_expr); R 267]
  | 1049 -> One [R 267]
  | 1050 -> One [R 245]
  | 1051 -> One [S (N N_expr); R 259]
  | 1052 -> One [R 259]
  | 1053 -> One [S (N N_expr); R 260]
  | 1054 -> One [R 260]
  | 1055 -> One [S (N N_expr); R 261]
  | 1056 -> One [R 261]
  | 1057 -> One [S (N N_expr); R 262]
  | 1058 -> One [R 262]
  | 1059 -> One [r339]
  | 1060 -> One [R 280]
  | 1061 -> One [R 285]
  | 1062 -> One [R 283]
  | 1063 -> One [R 442]
  | 1064 -> One [S (T T_RPAREN); R 819]
  | 1065 -> One [R 819]
  | 1066 -> One [r124; r341]
  | 1067 -> One [R 326; R 336]
  | 1068 -> One [R 336]
  | 1069 -> One [r341]
  | 1070 -> One [R 828]
  | 1071 -> One [S (T T_SLASHGREATER); R 339]
  | 1072 -> One [R 339]
  | 1073 -> One [R 406; r342]
  | 1074 -> One [r342]
  | 1075 -> One [R 340]
  | 1076 -> One [S (N N_simple_expr_no_call); r343]
  | 1077 -> One [r343]
  | 1078 -> One [S (T T_LIDENT); R 876]
  | 1079 -> One [R 876]
  | 1080 -> One [R 860]
  | 1081 -> One [S (N N_simple_expr_no_call); R 879]
  | 1082 -> One [R 879]
  | 1083 -> One [R 341]
  | 1084 -> One [r345]
  | 1085 -> One [r344]
  | 1086 -> One [R 864]
  | 1087 -> One [S (T T_LBRACKET); r347]
  | 1088 -> One [r347]
  | 1089 -> One [r346]
  | 1090 -> One [R 865]
  | 1091 -> One [r348; r350]
  | 1092 -> One [r350]
  | 1093 -> One [R 643]
  | 1094 -> One [R 441]
  | 1095 -> One [r349]
  | 1096 -> One [R 866]
  | 1097 -> One [R 440]
  | 1098 -> One [R 862]
  | 1099 -> One [r351; r352]
  | 1100 -> One [r352]
  | 1101 -> One [R 827]
  | 1102 -> One [S (T T_RBRACKET); R 829]
  | 1103 -> One [R 829]
  | 1104 -> One [S (T T_RBRACKET); R 830]
  | 1105 -> One [R 830]
  | 1106 -> One [r353; r355]
  | 1107 -> One [r355]
  | 1108 -> One [R 643]
  | 1109 -> One [R 445]
  | 1110 -> One [r354]
  | 1111 -> One [R 833]
  | 1112 -> One [R 444]
  | 1113 -> One [r326]
  | 1114 -> One [r358]
  | 1115 -> One [R 1007]
  | 1116 -> One [r357]
  | 1117 -> One [r356]
  | 1118 -> One [R 643]
  | 1119 -> One [R 740]
  | 1120 -> One [R 821]
  | 1121 -> One [r127; r363]
  | 1122 -> One [r363]
  | 1123 -> One [R 646; r364; r365]
  | 1124 -> One [r364]
  | 1125 -> One [R 459]
  | 1126 -> One [S (N N_expr); R 458]
  | 1127 -> One [R 458]
  | 1128 -> One [r365]
  | 1129 -> One [R 643]
  | 1130 -> One [r245; R 461]
  | 1131 -> One [R 461]
  | 1132 -> One [S (N N_expr); R 460]
  | 1133 -> One [R 460]
  | 1134 -> One [R 726]
  | 1135 -> One [r362]
  | 1136 -> One [r366]
  | 1137 -> One [S (N N_expr); R 667]
  | 1138 -> One [R 667]
  | 1139 -> One [R 1006]
  | 1140 -> One [R 739]
  | 1141 -> One [R 470]
  | 1142 -> One [r361]
  | 1143 -> One [r360]
  | 1144 -> One [S (N N_expr); r368]
  | 1145 -> One [r368]
  | 1146 -> One [r367]
  | 1147 -> One [R 727]
  | 1148 -> One [R 643]
  | 1149 -> One [r245; R 414]
  | 1150 -> One [R 414]
  | 1151 -> One [S (N N_expr); R 413]
  | 1152 -> One [R 413]
  | 1153 -> One [R 724]
  | 1154 -> One [r359]
  | 1155 -> One [R 728]
  | 1156 -> One [R 725]
  | 1157 -> One [r369]
  | 1158 -> One [R 643]
  | 1159 -> One [R 471]
  | 1160 -> One [R 1009]
  | 1161 -> One [S (T T_STRING); r366; R 470; r369; R 741]
  | 1162 -> One [R 741]
  | 1163 -> One [S (T T_RBRACE); R 826]
  | 1164 -> One [R 826]
  | 1165 -> One [S (T T_RBRACE); R 825]
  | 1166 -> One [R 825]
  | 1167 -> One [S (T T_COLON); r371]
  | 1168 -> One [R 646; r374]
  | 1169 -> One [r374]
  | 1170 -> One [r373]
  | 1171 -> One [S (N N_expr); r376]
  | 1172 -> One [r376]
  | 1173 -> One [r375]
  | 1174 -> One [R 737]
  | 1175 -> One [R 733]
  | 1176 -> One [r372]
  | 1177 -> One [R 738]
  | 1178 -> One [R 734]
  | 1179 -> One [r371]
  | 1180 -> One [r370]
  | 1181 -> One [R 730]
  | 1182 -> One [R 643]
  | 1183 -> One [r245; r378]
  | 1184 -> One [r378]
  | 1185 -> One [S (N N_expr); r380]
  | 1186 -> One [r380]
  | 1187 -> One [r379]
  | 1188 -> One [R 735]
  | 1189 -> One [R 731]
  | 1190 -> One [r377]
  | 1191 -> One [R 736]
  | 1192 -> One [R 732]
  | 1193 -> One [R 729]
  | 1194 -> One [r324]
  | 1195 -> One [R 822]
  | 1196 -> One [S (N N_expr); R 274]
  | 1197 -> One [R 274]
  | 1198 -> One [r383]
  | 1199 -> One [r382]
  | 1200 -> One [r381]
  | 1201 -> One [R 823]
  | 1202 -> One [S (N N_expr); R 275]
  | 1203 -> One [R 275]
  | 1204 -> One [r386]
  | 1205 -> One [r385]
  | 1206 -> One [r384]
  | 1207 -> One [R 824]
  | 1208 -> One [S (N N_expr); R 276]
  | 1209 -> One [R 276]
  | 1210 -> One [R 820]
  | 1211 -> One [S (N N_expr); R 273]
  | 1212 -> One [R 273]
  | 1213 -> One [R 344]
  | 1214 -> One [R 840]
  | 1215 -> One [r324]
  | 1216 -> One [R 822]
  | 1217 -> One [r383]
  | 1218 -> One [r382]
  | 1219 -> One [r381]
  | 1220 -> One [R 823]
  | 1221 -> One [r386]
  | 1222 -> One [r385]
  | 1223 -> One [r384]
  | 1224 -> One [R 824]
  | 1225 -> One [R 820]
  | 1226 -> One [R 235]
  | 1227 -> One [r108; r388]
  | 1228 -> One [r388]
  | 1229 -> One [r387]
  | 1230 -> One [R 236]
  | 1231 -> One [r108; R 552]
  | 1232 -> One [r314]
  | 1233 -> One [R 184]
  | 1234 -> One [R 185]
  | 1235 -> One [r313]
  | 1236 -> One [r312]
  | 1237 -> One [r311]
  | 1238 -> One [R 243]
  | 1239 -> One [R 683]
  | 1240 -> One [R 357]
  | 1241 -> One [r305]
  | 1242 -> One [r108; R 669]
  | 1243 -> One [R 669]
  | 1244 -> One [r304]
  | 1245 -> One [r302]
  | 1246 -> One [R 202]
  | 1247 -> One [R 305]
  | 1248 -> One [R 203]
  | 1249 -> One [S (T T_RPAREN); r390]
  | 1250 -> One [r390]
  | 1251 -> One [r389]
  | 1252 -> One [R 307]
  | 1253 -> One [R 642; r393]
  | 1254 -> One [r393]
  | 1255 -> One [r392]
  | 1256 -> One [r391]
  | 1257 -> One [R 308]
  | 1258 -> One [R 642; r396]
  | 1259 -> One [r396]
  | 1260 -> One [r395]
  | 1261 -> One [r394]
  | 1262 -> One [R 306]
  | 1263 -> One [r58; r399]
  | 1264 -> One [r399]
  | 1265 -> One [S (N N_expr); R 677]
  | 1266 -> One [R 677]
  | 1267 -> One [r398]
  | 1268 -> One [r397]
  | 1269 -> One [R 486]
  | 1270 -> One [R 408; R 237]
  | 1271 -> One [R 237]
  | 1272 -> One [R 409]
  | 1273 -> One [R 234]
  | 1274 -> One [R 355]
  | 1275 -> One [R 351]
  | 1276 -> One [R 354]
  | 1277 -> One [r297]
  | 1278 -> One [R 350]
  | 1279 -> One [R 195]
  | 1280 -> One [R 349]
  | 1281 -> One [R 480]
  | 1282 -> One [R 348]
  | 1283 -> One [r295]
  | 1284 -> One [R 345]
  | 1285 -> One [R 642; r400]
  | 1286 -> One [R 643]
  | 1287 -> One [r296; R 481]
  | 1288 -> One [R 481]
  | 1289 -> One [r400]
  | 1290 -> One [R 346]
  | 1291 -> One [r345]
  | 1292 -> One [R 407]
  | 1293 -> One [r294]
  | 1294 -> One [R 324]
  | 1295 -> One [S (N N_simple_expr_no_call); r401]
  | 1296 -> One [r401]
  | 1297 -> One [R 325]
  | 1298 -> One [S (N N_expr); R 241]
  | 1299 -> One [R 241]
  | 1300 -> One [R 687]
  | 1301 -> One [R 714]
  | 1302 -> One [S (N N_expr); R 1160]
  | 1303 -> One [R 1160]
  | 1304 -> One [S (N N_expr); R 1159]
  | 1305 -> One [R 1159]
  | 1306 -> One [R 684; r402]
  | 1307 -> One [r402]
  | 1308 -> One [R 604]
  | 1310 -> One [r404]
  | 1311 -> One [R 653]
  | 1312 -> One [r403]
  | 1313 -> One [R 1031]
  | 1314 -> One [R 1033]
  | 1315 -> One [S (N N_expr); R 1158]
  | 1316 -> One [R 1158]
  | 1317 -> One [S (N N_expr); R 1157]
  | 1318 -> One [R 1157]
  | 1320 -> One [r410]
  | 1321 -> One [r409]
  | 1322 -> One [r408]
  | 1323 -> One [r407]
  | 1324 -> One [r406]
  | 1325 -> One [r405]
  | 1326 -> One [R 1133]
  | 1327 -> One [S (T T_RPAREN); R 817]
  | 1328 -> One [R 817]
  | 1330 -> One [r411]
  | 1331 -> One [R 1166]
  | 1332 -> One [r412]
  | 1333 -> One [R 721; r416]
  | 1334 -> One [R 722]
  | 1335 -> One [r416]
  | 1336 -> One [R 924]
  | 1337 -> One [r19; r418]
  | 1338 -> One [r418]
  | 1339 -> One [r417]
  | 1340 -> One [R 374]
  | 1341 -> One [R 923]
  | 1342 -> One [S (T T_RPAREN); r422]
  | 1343 -> One [r422]
  | 1344 -> One [r421]
  | 1345 -> One [r419]
  | 1346 -> One [R 200]
  | 1347 -> One [R 301]
  | 1348 -> One [R 201]
  | 1349 -> One [S (T T_RPAREN); r424]
  | 1350 -> One [r424]
  | 1351 -> One [r423]
  | 1352 -> One [R 303]
  | 1353 -> One [R 642; r427]
  | 1354 -> One [r427]
  | 1355 -> One [r426]
  | 1356 -> One [r425]
  | 1357 -> One [R 304]
  | 1358 -> One [R 642; r430]
  | 1359 -> One [r430]
  | 1360 -> One [r429]
  | 1361 -> One [r428]
  | 1362 -> One [R 302]
  | 1363 -> One [r299]
  | 1364 -> One [r431; r435]
  | 1365 -> One [R 560]
  | 1366 -> One [R 561]
  | 1367 -> One [r435]
  | 1368 -> One [r434]
  | 1369 -> One [r433]
  | 1370 -> One [r432]
  | 1371 -> One [R 372]
  | 1372 -> One [S (T T_DOT); r438]
  | 1373 -> One [r438]
  | 1374 -> One [r437]
  | 1375 -> One [r436]
  | 1376 -> One [R 371]
  | 1377 -> One [S (T T_EQUAL); r439]
  | 1378 -> One [r439]
  | 1379 -> One [R 369]
  | 1380 -> One [R 370]
  | 1381 -> One [r414]
  | 1382 -> One [r413]
  | 1383 -> One [R 373]
  | 1384 -> One [R 367]
  | 1385 -> One [R 661]
  | 1386 -> One [S (N N_simple_expr_call); R 1168]
  | 1387 -> One [R 1168]
  | 1388 -> One [r52; R 1039]
  | 1389 -> One [R 1039]
  | 1390 -> One [R 682; r441]
  | 1391 -> One [r441]
  | 1392 -> One [r440]
  | 1393 -> One [R 1129]
  | 1394 -> One [S (N N_expr); R 1130]
  | 1395 -> One [R 1130]
  | 1396 -> One [R 682; r442]
  | 1397 -> One [r442]
  | 1398 -> One [R 408; R 1126]
  | 1399 -> One [R 1126]
  | 1400 -> One [R 1123]
  | 1401 -> One [R 682; r450]
  | 1402 -> One [r450]
  | 1403 -> One [r449]
  | 1404 -> One [r448]
  | 1405 -> One [r447]
  | 1406 -> One [r446]
  | 1407 -> One [r445]
  | 1408 -> One [r444]
  | 1409 -> One [r443]
  | 1410 -> One [R 1132]
  | 1411 -> One [r281; r453]
  | 1412 -> One [r453]
  | 1413 -> One [r452]
  | 1414 -> One [r451]
  | 1415 -> One [R 1022]
  | 1416 -> One [r454; R 1020]
  | 1417 -> One [R 558]
  | 1418 -> One [R 559]
  | 1419 -> One [R 1020]
  | 1420 -> One [R 718]
  | 1421 -> One [r457; R 1000]
  | 1422 -> One [r154]
  | 1423 -> One [r455; R 293]
  | 1424 -> One [r458]
  | 1425 -> One [R 293]
  | 1426 -> One [r149]
  | 1427 -> One [r456]
  | 1428 -> One [R 298]
  | 1429 -> One [r192]
  | 1430 -> One [r191]
  | 1431 -> One [r455; R 295]
  | 1432 -> One [R 295]
  | 1433 -> One [r194]
  | 1434 -> One [r193]
  | 1435 -> One [r455; R 294]
  | 1436 -> One [R 294]
  | 1437 -> One [r195]
  | 1438 -> One [r455; R 297]
  | 1439 -> One [R 297]
  | 1440 -> One [r196]
  | 1441 -> One [r455; R 296]
  | 1442 -> One [R 296]
  | 1443 -> One [R 193]
  | 1444 -> One [R 192]
  | 1445 -> One [R 1000]
  | 1446 -> One [r319; r460]
  | 1447 -> One [r460]
  | 1448 -> One [r459]
  | 1449 -> One [R 1124]
  | 1450 -> One [r108; r462]
  | 1451 -> One [r462]
  | 1452 -> One [r461]
  | 1453 -> One [R 1125]
  | 1454 -> One [R 770; R 711]
  | 1455 -> One [r46; R 796]
  | 1456 -> One [R 796]
  | 1457 -> One [r281; r465]
  | 1458 -> One [r465]
  | 1459 -> One [r464]
  | 1460 -> One [r463]
  | 1461 -> One [R 777]
  | 1462 -> One [r454; R 775]
  | 1463 -> One [R 775]
  | 1464 -> One [r150; R 764]
  | 1465 -> One [R 764]
  | 1467 -> One [R 1184]
  | 1468 -> One [r475]
  | 1469 -> One [r472]
  | 1470 -> One [r471]
  | 1471 -> One [R 1117; r477; R 474; r479]
  | 1472 -> One [R 1118]
  | 1473 -> One [R 1119]
  | 1474 -> One [r477]
  | 1475 -> One [r476]
  | 1476 -> One [R 1112]
  | 1477 -> One [R 1080]
  | 1478 -> One [R 474]
  | 1479 -> One [r479]
  | 1480 -> One [R 643]
  | 1481 -> One [R 475]
  | 1482 -> One [r478]
  | 1483 -> One [R 417]
  | 1484 -> One [r470]
  | 1485 -> One [r469]
  | 1486 -> One [r483; R 124]
  | 1487 -> One [R 546; R 549]
  | 1488 -> One [R 549]
  | 1489 -> One [R 1183; R 550]
  | 1490 -> One [R 550]
  | 1491 -> One [R 124]
  | 1492 -> One [r482]
  | 1493 -> One [r481]
  | 1494 -> One [r480]
  | 1495 -> One [R 1182]
  | 1496 -> One [R 655]
  | 1497 -> One [R 1183; r486]
  | 1498 -> One [r486]
  | 1499 -> One [r485]
  | 1500 -> One [r484]
  | 1501 -> One [R 128]
  | 1502 -> One [R 1183; r489]
  | 1503 -> One [r489]
  | 1504 -> One [r488]
  | 1505 -> One [r487]
  | 1506 -> One [R 126]
  | 1507 -> One [R 649]
  | 1508 -> One [r491; R 122]
  | 1509 -> One [R 145]
  | 1510 -> One [S (T T_DOT); r492]
  | 1511 -> One [r492]
  | 1512 -> One [R 146]
  | 1513 -> One [R 110]
  | 1514 -> One [r490]
  | 1515 -> One [r155; r493; r494]
  | 1516 -> One [r493]
  | 1517 -> One [R 139]
  | 1518 -> One [r494]
  | 1519 -> One [R 425]
  | 1520 -> One [R 107]
  | 1521 -> One [R 109]
  | 1522 -> One [R 122]
  | 1523 -> One [r491; R 108]
  | 1524 -> One [R 108]
  | 1525 -> One [r467; r495]
  | 1526 -> One [r498; R 130]
  | 1527 -> One [r497]
  | 1528 -> One [r496]
  | 1529 -> One [R 157]
  | 1530 -> One [R 130]
  | 1531 -> One [r19; R 114]
  | 1532 -> One [R 114]
  | 1533 -> One [R 120]
  | 1534 -> One [S (T T_OPEN); r502]
  | 1535 -> One [r502]
  | 1536 -> One [r501]
  | 1537 -> One [r500]
  | 1538 -> One [r499]
  | 1539 -> One [R 134]
  | 1540 -> One [r483; R 125]
  | 1541 -> One [R 125]
  | 1542 -> One [R 1183; r505]
  | 1543 -> One [r505]
  | 1544 -> One [r504]
  | 1545 -> One [r503]
  | 1546 -> One [R 129]
  | 1547 -> One [R 1183; r508]
  | 1548 -> One [r508]
  | 1549 -> One [r507]
  | 1550 -> One [r506]
  | 1551 -> One [R 127]
  | 1552 -> One [r491; R 123]
  | 1553 -> One [R 123]
  | 1554 -> One [r498; R 131]
  | 1555 -> One [R 131]
  | 1556 -> One [R 133]
  | 1557 -> One [R 654; R 121]
  | 1558 -> One [R 655]
  | 1559 -> One [R 132]
  | 1560 -> One [R 485]
  | 1561 -> One [R 121]
  | 1562 -> One [R 484]
  | 1563 -> One [R 117]
  | 1564 -> One [R 119]
  | 1565 -> One [R 118]
  | 1566 -> One [R 115]
  | 1567 -> One [r466; R 116]
  | 1568 -> One [R 116]
  | 1569 -> One [r495]
  | 1570 -> One [R 141]
  | 1571 -> One [r468]
  | 1572 -> One [R 140]
  | 1573 -> One [r491; R 198]
  | 1574 -> One [R 198]
  | 1575 -> One [R 142]
  | 1576 -> One [R 199]
  | 1577 -> One [r474]
  | 1578 -> One [r473; R 15]
  | 1579 -> One [R 15]
  | 1580 -> One [S (T T_AND); r509]
  | 1581 -> One [r509]
  | 1582 -> One [R 16]
  | 1583 -> One [R 143]
  | 1584 -> One [R 385; R 386]
  | 1585 -> One [R 386]
  | 1586 -> One [r514]
  | 1587 -> One [r513]
  | 1588 -> One [r512]
  | 1589 -> One [r511]
  | 1590 -> One [R 65]
  | 1591 -> One [R 78]
  | 1592 -> One [S (T T_EQUALGREATER); r515]
  | 1593 -> One [r515]
  | 1594 -> One [R 66]
  | 1595 -> One [r516]
  | 1596 -> One [r517; R 13]
  | 1597 -> One [R 13]
  | 1598 -> One [S (T T_AND); r518]
  | 1599 -> One [r518]
  | 1600 -> One [R 14]
  | 1601 -> One [R 79]
  | 1602 -> One [R 383; R 384]
  | 1603 -> One [R 384]
  | 1604 -> One [R 780]
  | 1605 -> One [R 779]
  | 1606 -> One [R 771]
  | 1607 -> One [R 770; R 772]
  | 1608 -> One [R 802]
  | 1609 -> One [R 772]
  | 1610 -> One [R 781]
  | 1611 -> One [R 782]
  | 1612 -> One [S (T T_EQUAL); r519]
  | 1613 -> One [r519]
  | 1614 -> One [R 785]
  | 1615 -> One [R 783]
  | 1616 -> One [r520; R 520]
  | 1617 -> One [r46; R 539]
  | 1618 -> One [R 539]
  | 1619 -> One [R 540]
  | 1620 -> One [R 520]
  | 1621 -> One [R 419]
  | 1622 -> One [r520; r521]
  | 1623 -> One [r521]
  | 1624 -> One [r258; r522]
  | 1625 -> One [r522]
  | 1626 -> One [R 19]
  | 1627 -> One [S (T T_AND); r524]
  | 1628 -> One [r524]
  | 1629 -> One [r523]
  | 1630 -> One [R 20]
  | 1631 -> One [R 789]
  | 1632 -> One [R 392; R 393]
  | 1633 -> One [R 393]
  | 1636 -> One [r525]
  | 1637 -> One [R 787]
  | 1638 -> One [r258; R 638]
  | 1639 -> One [R 639]
  | 1640 -> One [R 638]
  | 1641 -> One [R 641]
  | 1642 -> One [R 640]
  | 1643 -> One [R 795]
  | 1644 -> One [R 803]
  | 1645 -> One [r527]
  | 1646 -> One [r526]
  | 1647 -> One [r90]
  | 1648 -> One [r89]
  | 1649 -> One [R 225; r528]
  | 1650 -> One [r528]
  | 1651 -> One [R 768]
  | 1652 -> One [R 1092]
  | 1653 -> One [R 1063]
  | 1654 -> One [S (T T_DOT); r533]
  | 1655 -> One [r533]
  | 1656 -> One [r532]
  | 1657 -> One [r531]
  | 1658 -> One [r530]
  | 1659 -> One [r529]
  | 1660 -> One [R 769]
  | 1661 -> One [R 684; r534]
  | 1662 -> One [r534]
  | 1663 -> One [R 607]
  | 1664 -> One [S (T T_TYPE); r535]
  | 1665 -> One [r535]
  | 1666 -> One [R 792]
  | 1667 -> One [R 794]
  | 1668 -> One [r412]
  | 1669 -> One [S (T T_COLON); r536]
  | 1670 -> One [r536]
  | 1671 -> One [R 774]
  | 1672 -> One [r46; R 797]
  | 1673 -> One [R 797]
  | 1674 -> One [r281; r539]
  | 1675 -> One [r539]
  | 1676 -> One [r538]
  | 1677 -> One [r537]
  | 1678 -> One [R 778]
  | 1679 -> One [r454; R 776]
  | 1680 -> One [R 776]
  | 1681 -> One [r150; R 765]
  | 1682 -> One [R 765]
  | 1684 -> One [r541]
  | 1685 -> One [r540]
  | 1686 -> One [R 144]
  | 1687 -> One [r542]
  | 1688 -> One [R 80]
  | 1689 -> One [S (T T_EQUAL); r543]
  | 1690 -> One [r543]
  | 1691 -> One [R 786]
  | 1692 -> One [R 784]
  | 1693 -> One [r520; r544]
  | 1694 -> One [r544]
  | 1695 -> One [R 790]
  | 1696 -> One [r545]
  | 1697 -> One [S (T T_COLONEQUAL); r546]
  | 1698 -> One [r546]
  | 1699 -> One [R 788]
  | 1700 -> One [R 801]
  | 1701 -> One [R 800]
  | 1702 -> One [R 799]
  | 1703 -> One [R 798]
  | 1704 -> One [R 711]
  | 1705 -> One [R 803]
  | 1706 -> One [R 712]
  | 1707 -> One [r555; r556]
  | 1708 -> One [r554]
  | 1709 -> One [r553]
  | 1710 -> One [S (T T_RPAREN); r557]
  | 1711 -> One [r557]
  | 1712 -> One [r510; R 663]
  | 1713 -> One [R 663]
  | 1714 -> One [r551]
  | 1715 -> One [r550]
  | 1716 -> One [R 188]
  | 1717 -> One [R 189]
  | 1718 -> One [r558; r559]
  | 1719 -> One [r548; r560]
  | 1720 -> One [R 649]
  | 1721 -> One [S (N N_simple_expr_call); R 102]
  | 1722 -> One [R 102]
  | 1723 -> One [R 684; r562]
  | 1724 -> One [r562]
  | 1725 -> One [r35; r563]
  | 1726 -> One [r563]
  | 1727 -> One [R 435]
  | 1728 -> One [R 88]
  | 1729 -> One [R 89]
  | 1730 -> One [S (T T_LPAREN); r566]
  | 1731 -> One [r566]
  | 1732 -> One [r565]
  | 1733 -> One [r564]
  | 1734 -> One [R 81]
  | 1735 -> One [R 86]
  | 1736 -> One [R 135]
  | 1737 -> One [R 82]
  | 1738 -> One [r558; R 87]
  | 1739 -> One [R 87]
  | 1740 -> One [S (T T_RPAREN); r568]
  | 1741 -> One [r568]
  | 1742 -> One [r567]
  | 1743 -> One [R 84]
  | 1744 -> One [R 642; r571]
  | 1745 -> One [r571]
  | 1746 -> One [r570]
  | 1747 -> One [r569]
  | 1748 -> One [R 85]
  | 1749 -> One [R 642; r574]
  | 1750 -> One [r574]
  | 1751 -> One [r573]
  | 1752 -> One [r572]
  | 1753 -> One [R 83]
  | 1754 -> One [r561]
  | 1755 -> One [S (T T_LIDENT); R 657]
  | 1756 -> One [R 657]
  | 1757 -> One [R 94]
  | 1758 -> One [r498; R 100]
  | 1759 -> One [R 100]
  | 1760 -> One [R 591]
  | 1761 -> One [S (T T_OPEN); r578]
  | 1762 -> One [r578]
  | 1763 -> One [r577]
  | 1764 -> One [r576]
  | 1765 -> One [r575]
  | 1766 -> One [R 590]
  | 1767 -> One [R 92]
  | 1768 -> One [R 421]
  | 1769 -> One [r14; R 97]
  | 1770 -> One [R 97]
  | 1771 -> One [r13]
  | 1772 -> One [R 547]
  | 1773 -> One [S (T T_LIDENT); r580]
  | 1774 -> One [r580]
  | 1775 -> One [r579]
  | 1776 -> One [R 1176]
  | 1777 -> One [S (T T_EQUAL); r581]
  | 1778 -> One [r581]
  | 1779 -> One [R 1177]
  | 1780 -> One [r12]
  | 1781 -> One [r11]
  | 1782 -> One [r10]
  | 1783 -> One [R 1180]
  | 1784 -> One [S (T T_EQUAL); r582]
  | 1785 -> One [r582]
  | 1786 -> One [R 1181]
  | 1787 -> One [r585]
  | 1788 -> One [r584]
  | 1789 -> One [r583]
  | 1790 -> One [R 368]
  | 1791 -> One [S (N N_simple_expr_call); R 103]
  | 1792 -> One [R 103]
  | 1793 -> One [R 684; r587]
  | 1794 -> One [r587]
  | 1795 -> One [r586]
  | 1796 -> One [R 95]
  | 1797 -> One [r498; R 101]
  | 1798 -> One [R 101]
  | 1799 -> One [R 105]
  | 1800 -> One [r591; R 99]
  | 1801 -> One [r590]
  | 1802 -> One [S (T T_LIDENT); r593]
  | 1803 -> One [r593]
  | 1804 -> One [r592]
  | 1805 -> One [R 488]
  | 1806 -> One [r589]
  | 1807 -> One [r162; R 671]
  | 1808 -> One [r431; r596]
  | 1809 -> One [r596]
  | 1810 -> One [r595]
  | 1811 -> One [r594]
  | 1812 -> One [R 491]
  | 1813 -> One [R 671]
  | 1814 -> One [r588]
  | 1815 -> One [R 490]
  | 1816 -> One [R 489]
  | 1817 -> One [R 99]
  | 1818 -> One [R 654; R 592]
  | 1819 -> One [R 655]
  | 1820 -> One [R 106]
  | 1821 -> One [R 104]
  | 1822 -> One [r591; R 98]
  | 1823 -> One [R 98]
  | 1824 -> One [R 483]
  | 1825 -> One [R 592]
  | 1826 -> One [S (T T_AS); r597; R 588]
  | 1827 -> One [r597]
  | 1828 -> One [R 113]
  | 1829 -> One [R 588]
  | 1830 -> One [r547; R 589]
  | 1831 -> One [R 589]
  | 1832 -> One [R 482]
  | 1833 -> One [S (T T_SEMI); r598]
  | 1834 -> One [r598]
  | 1835 -> One [R 387; R 375]
  | 1836 -> One [r415; r599]
  | 1837 -> One [r599]
  | 1838 -> One [S (T T_AND); r601]
  | 1839 -> One [r601]
  | 1840 -> One [r600]
  | 1841 -> One [R 389]
  | 1842 -> One [R 388]
  | 1843 -> One [R 375]
  | 1844 -> One [R 91]
  | 1845 -> One [R 90]
  | 1846 -> One [R 562]
  | 1847 -> One [R 93]
  | 1848 -> One [r560]
  | 1849 -> One [R 136]
  | 1850 -> One [r559]
  | 1851 -> One [R 138]
  | 1852 -> One [r510; r602]
  | 1853 -> One [r602]
  | 1854 -> One [R 137]
  | 1855 -> One [r549]
  | 1856 -> One [R 197]
  | 1857 -> One [r558; R 196]
  | 1858 -> One [R 196]
  | 1859 -> One [R 67]
  | 1860 -> One [R 69]
  | 1861 -> One [R 1118]
  | 1862 -> One [R 1119]
  | 1863 -> One [S (T T_RPAREN); r603]
  | 1864 -> One [r603]
  | 1865 -> One [R 71]
  | 1866 -> One [R 642; r605]
  | 1867 -> One [r605]
  | 1868 -> One [r604]
  | 1869 -> One [R 72]
  | 1870 -> One [R 642; r607]
  | 1871 -> One [r607]
  | 1872 -> One [r606]
  | 1873 -> One [S (T T_RPAREN); r608]
  | 1874 -> One [r608]
  | 1875 -> One [R 74]
  | 1876 -> One [S (T T_RPAREN); r609]
  | 1877 -> One [r609]
  | 1878 -> One [R 76]
  | 1879 -> One [R 642; r611]
  | 1880 -> One [r611]
  | 1881 -> One [r610]
  | 1882 -> One [R 77]
  | 1883 -> One [R 642; r613]
  | 1884 -> One [r613]
  | 1885 -> One [r612]
  | 1886 -> One [R 75]
  | 1887 -> One [R 73]
  | 1888 -> One [R 642; r615]
  | 1889 -> One [r615]
  | 1890 -> One [r614]
  | 1891 -> One [R 70]
  | 1892 -> One [R 68]
  | 1893 -> One [r556]
  | 1894 -> One [r555; R 11]
  | 1895 -> One [R 11]
  | 1896 -> One [S (T T_AND); r616]
  | 1897 -> One [r616]
  | 1898 -> One [R 12]
  | 1899 -> One [R 1036]
  | 1900 -> One [R 381; R 382]
  | 1901 -> One [R 382]
  | 1902 -> One [S (N N_expr); R 1161]
  | 1903 -> One [R 1161]
  | 1904 -> One [S (N N_simple_expr_call); R 1167]
  | 1905 -> One [R 1167]
  | 1906 -> One [R 929]
  | 1907 -> One [R 1016]
  | 1908 -> One [S (N N_expr); R 1145]
  | 1909 -> One [R 1145]
  | 1910 -> One [S (N N_expr); R 1139]
  | 1911 -> One [R 1139]
  | 1912 -> One [S (N N_expr); r618]
  | 1913 -> One [r618]
  | 1914 -> One [r617]
  | 1915 -> One [R 1169]
  | 1916 -> One [S (N N_expr); R 1152]
  | 1917 -> One [R 1152]
  | 1918 -> One [S (N N_expr); R 1142]
  | 1919 -> One [R 1142]
  | 1920 -> One [S (N N_expr); R 1141]
  | 1921 -> One [R 1141]
  | 1922 -> One [S (N N_expr); R 1153]
  | 1923 -> One [R 1153]
  | 1924 -> One [S (N N_expr); R 1147]
  | 1925 -> One [R 1147]
  | 1926 -> One [S (N N_expr); R 1144]
  | 1927 -> One [R 1144]
  | 1928 -> One [S (N N_expr); R 1143]
  | 1929 -> One [R 1143]
  | 1930 -> One [S (N N_expr); R 1155]
  | 1931 -> One [R 1155]
  | 1932 -> One [S (N N_expr); R 1146]
  | 1933 -> One [R 1146]
  | 1934 -> One [S (N N_expr); R 1140]
  | 1935 -> One [R 1140]
  | 1936 -> One [S (N N_expr); R 1138]
  | 1937 -> One [R 1138]
  | 1938 -> One [S (N N_expr); R 1137]
  | 1939 -> One [R 1137]
  | 1940 -> One [S (N N_expr); R 1136]
  | 1941 -> One [R 1136]
  | 1942 -> One [S (N N_expr); R 1135]
  | 1943 -> One [R 1135]
  | 1944 -> One [S (N N_expr); R 1154]
  | 1945 -> One [R 1154]
  | 1946 -> One [S (N N_expr); R 1134]
  | 1947 -> One [S (N N_expr); R 1156]
  | 1948 -> One [R 1156]
  | 1949 -> One [R 1134]
  | 1950 -> One [S (N N_expr); R 1151]
  | 1951 -> One [R 1151]
  | 1952 -> One [S (N N_expr); R 1148]
  | 1953 -> One [R 1148]
  | 1954 -> One [S (N N_expr); R 1149]
  | 1955 -> One [R 1149]
  | 1956 -> One [S (N N_expr); R 1150]
  | 1957 -> One [R 1150]
  | 1958 -> One [R 1024]
  | 1959 -> One [R 1014]
  | 1960 -> One [R 1013; R 1015]
  | 1961 -> One [R 1015]
  | 1962 -> One [R 1025]
  | 1963 -> One [R 1026]
  | 1964 -> One [R 1122]
  | 1968 -> One [r619]
  | 1969 -> One [R 1163]
  | 1974 -> One [r620]
  | 1975 -> One [R 1164]
  | 1980 -> One [r621]
  | 1981 -> One [R 1165]
  | 1983 -> One [r622]
  | 1984 -> One [R 1162]
  | 1985 -> One [r626; R 1027]
  | 1986 -> One [R 1027]
  | 1987 -> One [r625]
  | 1988 -> One [r623]
  | 1989 -> One [R 529]
  | 1990 -> One [r46; r627]
  | 1991 -> One [r627]
  | 1992 -> One [R 530]
  | 1993 -> One [R 513]
  | 1994 -> One [R 512]
  | 1995 -> One [r626; r628]
  | 1996 -> One [r628]
  | 1997 -> One [r258; r629]
  | 1998 -> One [r629]
  | 1999 -> One [R 17]
  | 2000 -> One [S (T T_AND); r631]
  | 2001 -> One [r631]
  | 2002 -> One [r630]
  | 2003 -> One [R 18]
  | 2004 -> One [R 1029]
  | 2005 -> One [R 390; R 391]
  | 2006 -> One [R 391]
  | 2007 -> One [r545]
  | 2008 -> One [R 1035]
  | 2009 -> One [R 1044]
  | 2010 -> One [r527]
  | 2011 -> One [r526]
  | 2012 -> One [r90]
  | 2013 -> One [r89]
  | 2014 -> One [R 225; r634]
  | 2015 -> One [r634]
  | 2016 -> One [r457; R 566]
  | 2017 -> One [r457; R 567]
  | 2018 -> One [R 567]
  | 2019 -> One [R 571]
  | 2020 -> One [S (T T_BAR); r635]
  | 2021 -> One [r635]
  | 2022 -> One [r457; R 569]
  | 2023 -> One [R 569]
  | 2024 -> One [R 573]
  | 2025 -> One [R 568]
  | 2026 -> One [R 572]
  | 2027 -> One [R 566]
  | 2028 -> One [R 570]
  | 2029 -> One [R 39]
  | 2030 -> One [r632]
  | 2031 -> One [r457; r636]
  | 2032 -> One [r457; r637]
  | 2033 -> One [r637]
  | 2034 -> One [S (T T_BAR); r639]
  | 2035 -> One [r639]
  | 2036 -> One [r457; r640]
  | 2037 -> One [r640]
  | 2038 -> One [R 398]
  | 2039 -> One [r638]
  | 2040 -> One [R 397]
  | 2041 -> One [R 396]
  | 2042 -> One [r636]
  | 2043 -> One [R 395]
  | 2044 -> One [R 38]
  | 2045 -> One [R 1004]
  | 2046 -> One [S (T T_DOT); r645]
  | 2047 -> One [r645]
  | 2048 -> One [r644]
  | 2049 -> One [r643]
  | 2050 -> One [r642]
  | 2051 -> One [r641]
  | 2052 -> One [R 1005]
  | 2053 -> One [R 684; r646]
  | 2054 -> One [r646]
  | 2055 -> One [R 605]
  | 2056 -> One [S (T T_TYPE); r648]
  | 2057 -> One [r648]
  | 2058 -> One [r647]
  | 2059 -> One [R 1032]
  | 2060 -> One [R 1034]
  | 2062 -> One [r52; R 1040]
  | 2063 -> One [R 1040]
  | 2064 -> One [r281; r651]
  | 2065 -> One [r651]
  | 2066 -> One [r650]
  | 2067 -> One [r649]
  | 2068 -> One [R 1023]
  | 2069 -> One [r454; R 1021]
  | 2070 -> One [R 1021]
  | 2071 -> One [r457; R 1001]
  | 2072 -> One [R 1001]
  | 2073 -> One [r555; r652]
  | 2074 -> One [r652]
  | 2075 -> One [R 1037]
  | 2076 -> One [R 1017]
  | 2077 -> One [r626; R 1028]
  | 2078 -> One [R 1028]
  | 2079 -> One [r626; r653]
  | 2080 -> One [r653]
  | 2081 -> One [R 1030]
  | 2082 -> One [r654; R 1019]
  | 2083 -> One [R 1019]
  | 2084 -> One [R 1043]
  | 2085 -> One [r654; R 1018]
  | 2086 -> One [R 1018]
  | 2087 -> One [R 1041]
  | 2088 -> One [R 1038]
  | 2089 -> One [R 1042]
  | 2090 -> One [R 710]
  | 2091 -> One [S (T T_EQUALGREATER); r655]
  | 2092 -> One [r655]
  | 2093 -> One [R 715]
  | 2094 -> One [r256]
  | 2095 -> One [R 320]
  | 2096 -> One [r42]
  | 2097 -> One [R 543]
  | 2098 -> One [R 515]
  | 2099 -> One [R 450]
  | 2100 -> One [r148]
  | 2101 -> One [R 509]
  | 2102 -> One [R 642; R 511]
  | 2103 -> One [R 643]
  | 2104 -> One [R 451]
  | 2105 -> One [R 511]
  | 2106 -> One [r146]
  | 2107 -> One [r145]
  | 2108 -> One [R 880]
  | 2109 -> One [S (T T_RPAREN); R 861]
  | 2110 -> One [R 861]
  | 2111 -> One [r124; r656]
  | 2112 -> One [r656]
  | 2113 -> One [R 870]
  | 2114 -> One [r351; r657]
  | 2115 -> One [r657]
  | 2116 -> One [R 869]
  | 2117 -> One [S (T T_RBRACKET); R 871]
  | 2118 -> One [R 871]
  | 2119 -> One [S (T T_RBRACKET); R 872]
  | 2120 -> One [R 872]
  | 2121 -> One [r353; r659]
  | 2122 -> One [r659]
  | 2123 -> One [r658]
  | 2124 -> One [R 875]
  | 2125 -> One [r143]
  | 2126 -> One [R 863]
  | 2127 -> One [S (T T_RBRACE); R 868]
  | 2128 -> One [R 868]
  | 2129 -> One [S (T T_RBRACE); R 867]
  | 2130 -> One [R 867]
  | 2131 -> One [S (N N_simple_expr_call); R 910]
  | 2132 -> One [R 910]
  | 2133 -> One [S (T T_LIDENT); R 908]
  | 2134 -> One [R 908]
  | 2135 -> One [R 892]
  | 2136 -> One [S (N N_simple_expr_no_call); R 911]
  | 2137 -> One [R 911]
  | 2138 -> One [S (N N_expr); r660]
  | 2139 -> One [r660]
  | 2140 -> One [R 896]
  | 2141 -> One [r137]
  | 2142 -> One [r62]
  | 2143 -> One [r61]
  | 2144 -> One [r60]
  | 2145 -> One [r59]
  | 2146 -> One [R 636]
  | 2147 -> One [r281; R 929; r661; R 379; r663]
  | 2148 -> One [r661]
  | 2149 -> One [R 376]
  | 2150 -> One [R 701]
  | 2151 -> One [r19; r665]
  | 2152 -> One [r665]
  | 2153 -> One [r664]
  | 2154 -> One [R 377]
  | 2155 -> One [S (T T_EQUAL); r666]
  | 2156 -> One [r666]
  | 2157 -> One [R 378]
  | 2158 -> One [r663]
  | 2159 -> One [r662]
  | 2160 -> One [R 649]
  | 2161 -> One [S (T T_SEMI); r667]
  | 2162 -> One [r667]
  | 2163 -> One [R 752]
  | 2164 -> One [R 760]
  | 2165 -> One [S (T T_OPEN); r671]
  | 2166 -> One [r671]
  | 2167 -> One [r670]
  | 2168 -> One [r669]
  | 2169 -> One [r668]
  | 2170 -> One [R 758]
  | 2171 -> One [r626; r673]
  | 2172 -> One [r673]
  | 2173 -> One [r672]
  | 2174 -> One [R 757]
  | 2175 -> One [r545]
  | 2176 -> One [R 648; r678]
  | 2177 -> One [R 649]
  | 2178 -> One [r678]
  | 2179 -> One [r677]
  | 2180 -> One [r676]
  | 2181 -> One [r675]
  | 2182 -> One [r674]
  | 2183 -> One [R 759]
  | 2184 -> One [R 654; R 762]
  | 2185 -> One [R 655]
  | 2186 -> One [R 761]
  | 2187 -> One [S (N N_seq_expr_no_seq); R 753]
  | 2188 -> One [R 753]
  | 2189 -> One [r679]
  | 2190 -> One [R 655]
  | 2191 -> One [R 755]
  | 2192 -> One [r679]
  | 2193 -> One [R 655]
  | 2194 -> One [R 754]
  | 2196 -> One [R 756]
  | 2197 -> One [R 762]
  | 2198 -> One [R 763]
  | 2199 -> One [r415; R 380]
  | 2200 -> One [R 380]
  | 2201 -> One [R 379]
  | 2202 -> One [R 487]
  | 2203 -> One [r136]
  | 2204 -> One [r135]
  | 2205 -> One [R 1127]
  | 2206 -> One [R 411]
  | 2207 -> One [S (T T_LBRACKET); r681]
  | 2208 -> One [r681]
  | 2209 -> One [r680]
  | 2210 -> One [R 897]
  | 2211 -> One [r348; r683]
  | 2212 -> One [r683]
  | 2213 -> One [r682]
  | 2214 -> One [R 898]
  | 2215 -> One [R 894]
  | 2216 -> One [R 886]
  | 2217 -> One [S (T T_DOT); r685]
  | 2218 -> One [r685]
  | 2219 -> One [r70]
  | 2220 -> One [r52; r688]
  | 2221 -> One [r688]
  | 2222 -> One [r687]
  | 2223 -> One [r686]
  | 2224 -> One [R 912]
  | 2225 -> One [S (T T_RPAREN); R 893]
  | 2226 -> One [R 893]
  | 2227 -> One [r124; r689]
  | 2228 -> One [r689]
  | 2229 -> One [R 902]
  | 2230 -> One [r351; r690]
  | 2231 -> One [r690]
  | 2232 -> One [R 901]
  | 2233 -> One [S (T T_RBRACKET); R 903]
  | 2234 -> One [R 903]
  | 2235 -> One [S (T T_RBRACKET); R 904]
  | 2236 -> One [R 904]
  | 2237 -> One [r353; r692]
  | 2238 -> One [r692]
  | 2239 -> One [r691]
  | 2240 -> One [R 907]
  | 2241 -> One [r684]
  | 2242 -> One [R 895]
  | 2243 -> One [S (T T_RBRACE); R 900]
  | 2244 -> One [R 900]
  | 2245 -> One [S (T T_RBRACE); R 899]
  | 2246 -> One [R 899]
  | 2247 -> One [R 885]
  | 2248 -> One [R 913]
  | 2249 -> One [R 889]
  | 2250 -> One [R 884]
  | 2251 -> One [r134]
  | 2252 -> One [R 531]
  | 2253 -> One [r133]
  | 2254 -> One [R 849]
  | 2255 -> One [r47; r693]
  | 2256 -> One [r693]
  | 2257 -> One [R 850]
  | 2258 -> One [R 642; r694]
  | 2259 -> One [r694]
  | 2260 -> One [R 556]
  | 2261 -> One [R 279]
  | 2262 -> One [R 299]
  | 2263 -> One [R 848]
  | 2264 -> One [R 642; r695]
  | 2265 -> One [r695]
  | 2266 -> One [R 847]
  | 2267 -> One [R 457]
  | 2268 -> One [r130]
  | 2269 -> One [R 814]
  | 2270 -> One [R 456]
  | 2271 -> One [r126]
  | 2272 -> One [R 855]
  | 2273 -> One [R 642; r696]
  | 2274 -> One [r696]
  | 2275 -> One [R 856]
  | 2276 -> One [r122]
  | 2277 -> One [R 338]
  | 2278 -> One [r125]
  | 2279 -> One [R 845]
  | 2280 -> One [S (T T_RBRACKET); R 846]
  | 2281 -> One [R 846]
  | 2282 -> One [S (T T_RBRACKET); R 844]
  | 2283 -> One [R 844]
  | 2284 -> One [r120]
  | 2285 -> One [r119]
  | 2286 -> One [r118]
  | 2287 -> One [r117]
  | 2288 -> One [R 1128]
  | 2289 -> One [r115]
  | 2290 -> One [R 36]
  | 2291 -> One [R 431]
  | 2292 -> One [r114]
  | 2293 -> One [R 54]
  | 2294 -> One [r113]
  | 2295 -> One [S (T T_BACKQUOTE); r697; R 429]
  | 2296 -> One [r697]
  | 2297 -> One [R 582]
  | 2298 -> One [R 583]
  | 2299 -> One [R 429]
  | 2300 -> One [r112]
  | 2301 -> One [R 55]
  | 2302 -> One [r107]
  | 2303 -> One [r106]
  | 2304 -> One [R 1082]
  | 2305 -> One [R 643]
  | 2306 -> One [R 642; r698]
  | 2307 -> One [r698]
  | 2308 -> One [R 1085]
  | 2309 -> One [R 642; r699]
  | 2310 -> One [R 643]
  | 2311 -> One [R 642; r700]
  | 2312 -> One [r700]
  | 2313 -> One [R 1086]
  | 2314 -> One [r699]
  | 2315 -> One [R 1084]
  | 2316 -> One [r104]
  | 2317 -> One [R 1083]
  | 2318 -> One [R 448]
  | 2319 -> One [S (T T_DOTDOT); R 1074]
  | 2320 -> One [R 1074]
  | 2321 -> One [r701]
  | 2322 -> One [r211]
  | 2323 -> One [R 175]
  | 2324 -> One [R 1071]
  | 2325 -> One [r174]
  | 2326 -> One [R 1072]
  | 2327 -> One [r702; R 176]
  | 2328 -> One [R 21; R 179]
  | 2329 -> One [R 179]
  | 2330 -> One [r229]
  | 2331 -> One [R 176]
  | 2332 -> One [r702; R 177]
  | 2333 -> One [R 177]
  | 2334 -> One [R 178]
  | 2335 -> One [R 1068]
  | 2336 -> One [R 1057]
  | 2337 -> One [R 1073]
  | 2338 -> One [R 1069]
  | 2339 -> One [r174]
  | 2340 -> One [R 1070]
  | 2341 -> One [R 1067]
  | 2342 -> One [S (T T_DOTDOT); R 1075]
  | 2343 -> One [S (T T_BAR); r701; R 1059]
  | 2344 -> One [R 1078]
  | 2345 -> One [r211]
  | 2346 -> One [R 1079]
  | 2347 -> One [R 1059]
  | 2348 -> One [R 1075]
  | 2349 -> One [R 1076]
  | 2350 -> One [r211]
  | 2351 -> One [R 1077]
  | 2352 -> One [R 1058]
  | 2353 -> One [R 1056]
  | 2354 -> One [R 1054]
  | 2355 -> One [r90]
  | 2356 -> One [r89]
  | 2357 -> One [R 225; r703]
  | 2358 -> One [r703]
  | 2359 -> One [R 1002]
  | 2360 -> One [S (T T_DOT); r708]
  | 2361 -> One [r708]
  | 2362 -> One [r707]
  | 2363 -> One [r706]
  | 2364 -> One [r705]
  | 2365 -> One [r704]
  | 2366 -> One [R 1003]
  | 2367 -> One [r84]
  | 2368 -> One [R 286]
  | 2369 -> One [R 277]
  | 2370 -> One [R 270]
  | 2371 -> One [S (T T_RPAREN); r713]
  | 2372 -> One [r713]
  | 2373 -> One [r712]
  | 2374 -> One [r711]
  | 2375 -> One [r710]
  | 2376 -> One [r709]
  | 2377 -> One [R 244]
  | 2378 -> One [R 271]
  | 2379 -> One [S (T T_RPAREN); R 859]
  | 2380 -> One [R 859]
  | 2381 -> One [R 873]
  | 2382 -> One [r80]
  | 2383 -> One [R 322]
  | 2384 -> One [R 831]
  | 2385 -> One [r79]
  | 2386 -> One [R 327]
  | 2387 -> One [r78]
  | 2388 -> One [R 329]
  | 2389 -> One [R 330]
  | 2390 -> One [R 328]
  | 2391 -> One [R 332]
  | 2392 -> One [r74]
  | 2393 -> One [r73]
  | 2394 -> One [r72]
  | 2395 -> One [r71]
  | 2396 -> One [R 238]
  | 2397 -> One [S (T T_RPAREN); R 891]
  | 2398 -> One [R 891]
  | 2399 -> One [R 905]
  | 2400 -> One [r67]
  | 2401 -> One [r66]
  | 2402 -> One [r65]
  | 2403 -> One [r64]
  | 2404 -> One [R 239]
  | 2405 -> One [R 516]
  | 2406 -> One [R 650; r714]
  | 2407 -> One [r714]
  | 2408 -> One [R 519]
  | 2409 -> One [R 650; r715]
  | 2410 -> One [r715]
  | 2411 -> One [R 517]
  | 2412 -> One [R 650; r716]
  | 2413 -> One [r716]
  | 2414 -> One [R 518]
  | 2415 -> One [R 524]
  | 2416 -> One [S (T T_RPAREN); R 523]
  | 2417 -> One [R 523]
  | 2418 -> One [r53]
  | 2419 -> One [R 922]
  | 2420 -> One [R 719]
  | 2421 -> One [R 47]
  | 2422 -> One [r32]
  | 2423 -> One [R 1052]
  | 2424 -> One [r20]
  | 2425 -> One [R 1178]
  | 2426 -> One [S (T T_EQUAL); r717]
  | 2427 -> One [r717]
  | 2428 -> One [R 1179]
  | 2429 -> One [R 96]
  | 2430 -> One [r358]
  | 2431 -> One [R 342]
  | 2432 -> One [r127; r719]
  | 2433 -> One [r719]
  | 2434 -> One [S (T T_RBRACE); R 61]
  | 2435 -> One [R 61]
  | 2436 -> One [R 643]
  | 2437 -> One [r718]
  | 2438 -> One [R 60]
  | 2439 -> One [r9]
  | 2440 -> One [R 59]
  | 2441 -> One [S (T T_RBRACE); R 63]
  | 2442 -> One [R 63]
  | 2443 -> One [S (T T_RBRACE); R 62]
  | 2444 -> One [R 62]
  | 2445 -> One [S (T T_RBRACE); R 64]
  | 2446 -> One [R 64]
  | 2447 -> One [R 421]
  | 2448 -> One [r720]
  | 2449 -> One [r327]
  | 2450 -> One [R 343]
  | 2451 -> One [r6]
  | 2452 -> One [R 242]
  | 2453 -> One [r0]
  | 2454 -> One [R 688]
  | 2455 -> One [S (T T_RPAREN); R 689]
  | 2456 -> One [R 689]
  | 2457 -> One [r3]
  | 2458 -> One [R 1131]
  | 2459 -> One [S (T T_EOF); R 318]
  | 2460 -> One [R 318]
  | 2461 -> One [R 0]
  | 2463 -> One [S (T T_EOF); R 319]
  | 2464 -> One [R 319]
  | 2465 -> One [R 1]
  | 2467 -> One [R 2]
  | 2468 -> One [S (T T_EOF); R 690]
  | 2469 -> One [R 690]
  | 2471 -> One [R 3]
  | 2472 -> One [S (T T_EOF); R 691]
  | 2473 -> One [R 691]
  | 2475 -> One [S (T T_EOF); R 692]
  | 2476 -> One [R 692]
  | 2477 -> One [R 4]
  | 2479 -> One [r40; r721]
  | 2480 -> One [r721]
  | 2481 -> One [R 224]
  | 2482 -> One [R 219]
  | 2483 -> One [R 220]
  | 2484 -> One [R 223]
  | 2485 -> One [R 221]
  | 2486 -> One [R 222]
  | 2487 -> One [R 1049]
  | 2488 -> One [R 204]
  | 2489 -> One [R 5]
  | 2490 -> One [S (T T_SEMI); R 206]
  | 2491 -> One [R 206]
  | 2492 -> One [S (T T_SEMI); R 205]
  | 2493 -> One [R 205]
  | 2494 -> One [R 1050]
  | 2496 -> One [R 207]
  | 2497 -> One [R 1170]
  | 2498 -> One [R 6]
  | 2499 -> One [S (T T_EOF); R 211]
  | 2500 -> One [r722; R 209]
  | 2501 -> One [R 209]
  | 2502 -> One [S (T T_EOF); R 210]
  | 2503 -> One [r722; R 208]
  | 2504 -> One [R 208]
  | 2505 -> One [R 1171]
  | 2506 -> One [R 210]
  | 2507 -> One [R 211]
  | 154 -> Select (function
    | -1 -> [r458]
    | _ -> [r70])
  | 156 -> Select (function
    | -1 -> [R 1172]
    | _ -> [S (T T_EQUAL); r81])
  | 195 -> Select (function
    | 193 | 497 | 500 | 2319 -> [r26]
    | _ -> [r158])
  | 219 -> Select (function
    | -1 -> [r142]
    | _ -> [R 646; r128; r131; r132])
  | 295 -> Select (function
    | 1363 -> [r41]
    | _ -> [r164])
  | 296 -> Select (function
    | 1363 -> [R 48]
    | _ -> [R 564])
  | 321 -> Select (function
    | 195 -> [r27]
    | _ -> [r175])
  | 422 -> Select (function
    | 195 | 288 -> [r230]
    | _ -> [r160])
  | 624 -> Select (function
    | -1 -> [R 636]
    | _ -> [S (T T_TYPE); r240])
  | 670 -> Select (function
    | -1 -> [r412]
    | _ -> [r281; r255])
  | 712 -> Select (function
    | -1 -> [r458]
    | _ -> [r70])
  | 726 -> Select (function
    | -1 -> [r142]
    | _ -> [r278; r264])
  | 759 -> Select (function
    | -1 -> [R 151]
    | _ -> [S (T T_DOT); r272])
  | 896 -> Select (function
    | 2480 -> [r239]
    | _ -> [r300])
  | 951 -> Select (function
    | -1 -> [R 151]
    | _ -> [r720])
  | 1309 -> Select (function
    | -1 -> [R 636]
    | _ -> [S (T T_TYPE); r404])
  | 1319 -> Select (function
    | 164 | 202 | 701 -> [r70]
    | -1 -> [r458]
    | _ -> [S (T T_COLONCOLON); r410])
  | 1329 -> Select (function
    | -1 | 164 | 202 | 701 -> [R 1172]
    | _ -> [S (T T_EQUAL); r411])
  | 1466 -> Select (function
    | -1 -> [r517; r516]
    | _ -> [S (T T_TYPE); r475])
  | 1634 -> Select (function
    | -1 -> [r545]
    | _ -> [S (T T_UIDENT); r723])
  | 1635 -> Select (function
    | -1 -> [R 504]
    | _ -> [r723])
  | 1683 -> Select (function
    | -1 -> [r517; r542]
    | _ -> [S (T T_TYPE); r541])
  | 1965 -> Select (function
    | -1 -> [r325]
    | _ -> [S (N N_expr); r725])
  | 1966 -> Select (function
    | -1 -> [r324]
    | _ -> [r725])
  | 1967 -> Select (function
    | -1 -> [R 822]
    | _ -> [r724])
  | 1970 -> Select (function
    | -1 -> [r383]
    | _ -> [S (T T_LBRACKET); r728])
  | 1971 -> Select (function
    | -1 -> [r382]
    | _ -> [r728])
  | 1972 -> Select (function
    | -1 -> [r381]
    | _ -> [r727])
  | 1973 -> Select (function
    | -1 -> [R 823]
    | _ -> [r726])
  | 1976 -> Select (function
    | -1 -> [r386]
    | _ -> [r348; r731])
  | 1977 -> Select (function
    | -1 -> [r385]
    | _ -> [r731])
  | 1978 -> Select (function
    | -1 -> [r384]
    | _ -> [r730])
  | 1979 -> Select (function
    | -1 -> [R 824]
    | _ -> [r729])
  | 1982 -> Select (function
    | -1 -> [R 820]
    | _ -> [S (T T_EQUAL); r622])
  | 2061 -> Select (function
    | -1 -> [r585]
    | _ -> [r412])
  | 2195 -> Select (function
    | 2187 -> [r337]
    | _ -> [R 562])
  | _ -> raise Not_found
let token_of_terminal (type a) (t : a MenhirInterpreter.terminal) (v : a) : token =
  match t with
  | MenhirInterpreter.T_error -> assert false
  | MenhirInterpreter.T_WITH -> WITH
  | MenhirInterpreter.T_WHILE -> WHILE
  | MenhirInterpreter.T_WHEN -> WHEN
  | MenhirInterpreter.T_VIRTUAL -> VIRTUAL
  | MenhirInterpreter.T_VAL -> VAL
  | MenhirInterpreter.T_UNDERSCORE -> UNDERSCORE
  | MenhirInterpreter.T_UIDENT -> UIDENT v
  | MenhirInterpreter.T_TYPE -> TYPE
  | MenhirInterpreter.T_TRY -> TRY
  | MenhirInterpreter.T_TRUE -> TRUE
  | MenhirInterpreter.T_TO -> TO
  | MenhirInterpreter.T_TILDE -> TILDE
  | MenhirInterpreter.T_THEN -> THEN
  | MenhirInterpreter.T_SWITCH -> SWITCH
  | MenhirInterpreter.T_STRUCT -> STRUCT
  | MenhirInterpreter.T_STRING -> STRING v
  | MenhirInterpreter.T_STAR -> STAR
  | MenhirInterpreter.T_SLASHGREATER -> SLASHGREATER
  | MenhirInterpreter.T_SIG -> SIG
  | MenhirInterpreter.T_SHARPOP -> SHARPOP v
  | MenhirInterpreter.T_SHARPEQUAL -> SHARPEQUAL
  | MenhirInterpreter.T_SHARP -> SHARP
  | MenhirInterpreter.T_SEMISEMI -> SEMISEMI
  | MenhirInterpreter.T_SEMI -> SEMI
  | MenhirInterpreter.T_RPAREN -> RPAREN
  | MenhirInterpreter.T_REC -> REC
  | MenhirInterpreter.T_RBRACKET -> RBRACKET
  | MenhirInterpreter.T_RBRACE -> RBRACE
  | MenhirInterpreter.T_QUOTE -> QUOTE
  | MenhirInterpreter.T_QUESTION -> QUESTION
  | MenhirInterpreter.T_PUB -> PUB
  | MenhirInterpreter.T_PRI -> PRI
  | MenhirInterpreter.T_PREFIXOP -> PREFIXOP v
  | MenhirInterpreter.T_POSTFIXOP -> POSTFIXOP v
  | MenhirInterpreter.T_PLUSEQ -> PLUSEQ
  | MenhirInterpreter.T_PLUSDOT -> PLUSDOT
  | MenhirInterpreter.T_PLUS -> PLUS
  | MenhirInterpreter.T_PERCENT -> PERCENT
  | MenhirInterpreter.T_OR -> OR
  | MenhirInterpreter.T_OPEN -> OPEN
  | MenhirInterpreter.T_OF -> OF
  | MenhirInterpreter.T_OBJECT -> OBJECT
  | MenhirInterpreter.T_NONREC -> NONREC
  | MenhirInterpreter.T_NEW -> NEW
  | MenhirInterpreter.T_NATIVEINT -> NATIVEINT v
  | MenhirInterpreter.T_MUTABLE -> MUTABLE
  | MenhirInterpreter.T_MODULE -> MODULE
  | MenhirInterpreter.T_MINUSGREATER -> MINUSGREATER
  | MenhirInterpreter.T_MINUSDOT -> MINUSDOT
  | MenhirInterpreter.T_MINUS -> MINUS
  | MenhirInterpreter.T_LPAREN -> LPAREN
  | MenhirInterpreter.T_LIDENT -> LIDENT v
  | MenhirInterpreter.T_LETOP -> LETOP v
  | MenhirInterpreter.T_LET -> LET
  | MenhirInterpreter.T_LESSUIDENT -> LESSUIDENT v
  | MenhirInterpreter.T_LESSSLASHIDENTGREATER -> LESSSLASHIDENTGREATER v
  | MenhirInterpreter.T_LESSSLASHGREATER -> LESSSLASHGREATER
  | MenhirInterpreter.T_LESSIDENT -> LESSIDENT v
  | MenhirInterpreter.T_LESSGREATER -> LESSGREATER
  | MenhirInterpreter.T_LESSDOTDOTGREATER -> LESSDOTDOTGREATER
  | MenhirInterpreter.T_LESS -> LESS
  | MenhirInterpreter.T_LBRACKETPERCENTPERCENT -> LBRACKETPERCENTPERCENT
  | MenhirInterpreter.T_LBRACKETPERCENT -> LBRACKETPERCENT
  | MenhirInterpreter.T_LBRACKETLESS -> LBRACKETLESS
  | MenhirInterpreter.T_LBRACKETGREATER -> LBRACKETGREATER
  | MenhirInterpreter.T_LBRACKETBAR -> LBRACKETBAR
  | MenhirInterpreter.T_LBRACKETAT -> LBRACKETAT
  | MenhirInterpreter.T_LBRACKET -> LBRACKET
  | MenhirInterpreter.T_LBRACELESS -> LBRACELESS
  | MenhirInterpreter.T_LBRACE -> LBRACE
  | MenhirInterpreter.T_LAZY -> LAZY
  | MenhirInterpreter.T_INT -> INT v
  | MenhirInterpreter.T_INITIALIZER -> INITIALIZER
  | MenhirInterpreter.T_INHERIT -> INHERIT
  | MenhirInterpreter.T_INFIXOP4 -> INFIXOP4 v
  | MenhirInterpreter.T_INFIXOP3 -> INFIXOP3 v
  | MenhirInterpreter.T_INFIXOP2 -> INFIXOP2 v
  | MenhirInterpreter.T_INFIXOP1 -> INFIXOP1 v
  | MenhirInterpreter.T_INFIXOP0 -> INFIXOP0 v
  | MenhirInterpreter.T_INCLUDE -> INCLUDE
  | MenhirInterpreter.T_IN -> IN
  | MenhirInterpreter.T_IF -> IF
  | MenhirInterpreter.T_GREATERRBRACE -> GREATERRBRACE
  | MenhirInterpreter.T_GREATERDOTDOTDOT -> GREATERDOTDOTDOT
  | MenhirInterpreter.T_GREATER -> GREATER
  | MenhirInterpreter.T_FUNCTOR -> FUNCTOR
  | MenhirInterpreter.T_FUNCTION -> FUNCTION
  | MenhirInterpreter.T_FUN -> FUN
  | MenhirInterpreter.T_FOR -> FOR
  | MenhirInterpreter.T_FLOAT -> FLOAT v
  | MenhirInterpreter.T_FALSE -> FALSE
  | MenhirInterpreter.T_EXTERNAL -> EXTERNAL
  | MenhirInterpreter.T_EXCEPTION -> EXCEPTION
  | MenhirInterpreter.T_ES6_FUN -> ES6_FUN
  | MenhirInterpreter.T_EQUALGREATER -> EQUALGREATER
  | MenhirInterpreter.T_EQUAL -> EQUAL
  | MenhirInterpreter.T_EOL -> EOL
  | MenhirInterpreter.T_EOF -> EOF
  | MenhirInterpreter.T_END -> END
  | MenhirInterpreter.T_ELSE -> ELSE
  | MenhirInterpreter.T_DOWNTO -> DOWNTO
  | MenhirInterpreter.T_DOTDOTDOT -> DOTDOTDOT
  | MenhirInterpreter.T_DOTDOT -> DOTDOT
  | MenhirInterpreter.T_DOT -> DOT
  | MenhirInterpreter.T_DONE -> DONE
  | MenhirInterpreter.T_DOCSTRING -> DOCSTRING v
  | MenhirInterpreter.T_DO -> DO
  | MenhirInterpreter.T_CONSTRAINT -> CONSTRAINT
  | MenhirInterpreter.T_COMMENT -> COMMENT v
  | MenhirInterpreter.T_COMMA -> COMMA
  | MenhirInterpreter.T_COLONGREATER -> COLONGREATER
  | MenhirInterpreter.T_COLONEQUAL -> COLONEQUAL
  | MenhirInterpreter.T_COLONCOLON -> COLONCOLON
  | MenhirInterpreter.T_COLON -> COLON
  | MenhirInterpreter.T_CLASS -> CLASS
  | MenhirInterpreter.T_CHAR -> CHAR v
  | MenhirInterpreter.T_BEGIN -> BEGIN
  | MenhirInterpreter.T_BARRBRACKET -> BARRBRACKET
  | MenhirInterpreter.T_BARBAR -> BARBAR
  | MenhirInterpreter.T_BAR -> BAR
  | MenhirInterpreter.T_BANG -> BANG
  | MenhirInterpreter.T_BACKQUOTE -> BACKQUOTE
  | MenhirInterpreter.T_ASSERT -> ASSERT
  | MenhirInterpreter.T_AS -> AS
  | MenhirInterpreter.T_ANDOP -> ANDOP v
  | MenhirInterpreter.T_AND -> AND
  | MenhirInterpreter.T_AMPERSAND -> AMPERSAND
  | MenhirInterpreter.T_AMPERAMPER -> AMPERAMPER
let nullable (type a) : a MenhirInterpreter.nonterminal -> bool =
  let open MenhirInterpreter in function
  | N_virtual_flag -> true
  | N_type_variance -> true
  | N_type_variables_with_variance -> true
  | N_type_subst_constructor_declarations_aux -> true
  | N_type_other_kind -> true
  | N_type_declaration_kind -> true
  | N_structure -> true
  | N_signature -> true
  | N_rec_flag -> true
  | N_payload -> true
  | N_override_flag -> true
  | N_optional_expr_extension -> true
  | N_optional -> true
  | N_option_type_constraint_ -> true
  | N_option_preceded_WHEN_expr__ -> true
  | N_option_preceded_COLONGREATER_core_type__ -> true
  | N_option_preceded_COLON_simple_module_type__ -> true
  | N_option_preceded_COLON_poly_type__ -> true
  | N_option_preceded_COLON_non_arrowed_core_type__ -> true
  | N_option_preceded_COLON_expr__ -> true
  | N_option_preceded_COLON_core_type__ -> true
  | N_option_preceded_COLON_class_constructor_type__ -> true
  | N_option_item_extension_sugar_ -> true
  | N_option_constructor_arguments_ -> true
  | N_option_as_loc_preceded_AS_LIDENT___ -> true
  | N_option_SEMI_ -> true
  | N_option_OF_ -> true
  | N_option_MODULE_ -> true
  | N_option_LET_ -> true
  | N_option_DOTDOTDOT_ -> true
  | N_option_DOT_ -> true
  | N_option_COMMA_ -> true
  | N_object_body_class_fields -> true
  | N_object_body -> true
  | N_nonrec_flag -> true
  | N_mutable_or_virtual_flags -> true
  | N_mutable_flag -> true
  | N_module_arguments_comma_list -> true
  | N_loption_type_parameters_ -> true
  | N_loption_terminated_pattern_comma_list_option_COMMA___ -> true
  | N_loption_row_field_list_ -> true
  | N_loption_preceded_GREATER_nonempty_list_name_tag___ -> true
  | N_loption_parenthesized_type_variables_with_variance_comma_list__ -> true
  | N_loption_parenthesized_class_type_arguments_comma_list__ -> true
  | N_loption_object_label_declarations_ -> true
  | N_loption_located_attributes_ -> true
  | N_loption_functor_parameters_ -> true
  | N_loption_class_type_parameters_ -> true
  | N_llist_aux_preceded_COMMA_opt_spread_lbl_expr___ -> true
  | N_llist_aux_match_case_seq_expr__ -> true
  | N_llist_aux_match_case_expr__ -> true
  | N_list_simple_expr_no_call_ -> true
  | N_list_bar_row_field_ -> true
  | N_list_attributed_ext_constructor_extension_constructor_declaration__ -> true
  | N_list_attributed_ext_constructor_either_extension_constructor_declaration_extension_constructor_rebind___ -> true
  | N_list_and_module_rec_declaration_ -> true
  | N_list_and_module_bindings_ -> true
  | N_list_and_let_binding_ -> true
  | N_list_and_class_type_declaration_ -> true
  | N_list_and_class_description_ -> true
  | N_list_and_class_declaration_ -> true
  | N_labeled_pattern_constraint -> true
  | N_jsx_arguments -> true
  | N_generalized_constructor_arguments -> true
  | N_embedded_private_flag_ -> true
  | N_embedded___anonymous_39_ -> true
  | N_constructor_declarations_aux -> true
  | N_class_sig_body_fields -> true
  | N_class_sig_body_cty -> true
  | N_class_sig_body -> true
  | N_class_expr_lets_and_rest -> true
  | N_boption_AMPERSAND_ -> true
  | N_and_type_subst_declaration -> true
  | N_and_type_declaration -> true
  | _ -> false
